#ifndef lint
static const char yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93";
#endif

#define YYBYACC 1
#define YYMAJOR 1
#define YYMINOR 9
#define YYPATCH 20130925

#define YYEMPTY        (-1)
#define yyclearin      (yychar = YYEMPTY)
#define yyerrok        (yyerrflag = 0)
#define YYRECOVERING() (yyerrflag != 0)

#define YYPREFIX "yy"

#define YYPURE 0

#line 22 "parse.y"
#include <sys/types.h>
#include <sys/stat.h>

#include <ctype.h>
#include <grp.h>
#include <pwd.h>
#include <string.h>
#include <syslog.h>

#include "fdm.h"
#include "deliver.h"
#include "fetch.h"
#include "match.h"

struct strb	*parse_tags;
struct macros	 parse_macros;
struct macro	*parse_last;	/* last command-line argument macro */

u_int		 parse_ruleidx;
u_int		 parse_actionidx;

ARRAY_DECL(, struct rule *) parse_rulestack;
struct rule	*parse_rule;

struct files	 parse_filestack;
struct file	*parse_file;

int		 yyparse(void);

int
parse_conf(const char *path, struct strings *macros)
{
	struct macro	*macro;
	FILE		*f;
	u_int		 i;

        if ((f = fopen(path, "r")) == NULL)
                return (-1);

	ARRAY_INIT(&parse_rulestack);
	parse_rule = NULL;

	ARRAY_INIT(&parse_filestack);
	parse_file = xmalloc(sizeof *parse_file);

	parse_file->f = f;
	parse_file->line = 0;
	parse_file->path = path;

	strb_create(&parse_tags);
	default_tags(&parse_tags, NULL);
	add_tag(&parse_tags, "home", "%s", conf.user_home);

	TAILQ_INIT(&parse_macros);
	parse_last = NULL;
	for (i = 0; i < ARRAY_LENGTH(macros); i++) {
		parse_last = extract_macro(ARRAY_ITEM(macros, i));
		TAILQ_INSERT_TAIL(&parse_macros, parse_last, entry);
	}

	parse_file->line++;
        yyparse();

	if (!ARRAY_EMPTY(&parse_rulestack))
		yyerror("missing }");
	ARRAY_FREE(&parse_rulestack);

	ARRAY_FREE(&parse_filestack);
	xfree(parse_file);

	while (!TAILQ_EMPTY(&parse_macros)) {
		macro = TAILQ_FIRST(&parse_macros);
		TAILQ_REMOVE(&parse_macros, macro, entry);

		if (macro->type == MACRO_STRING)
			xfree(macro->value.str);
		xfree(macro);
	}

	strb_destroy(&parse_tags);

        fclose(f);
        return (0);
}

__dead printflike1 void
yyerror(const char *fmt, ...)
{
	va_list	ap;
	char   *s;

	xasprintf(&s,
	    "%s: %s at line %d", parse_file->path, fmt, parse_file->line);

	va_start(ap, fmt);
	log_vwrite(LOG_CRIT, s, ap);
	va_end(ap);

	exit(1);
}
#line 248 "parse.y"
#ifdef YYSTYPE
#undef  YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
#endif
#ifndef YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
typedef union
{
	long long 	 	 number;
        char 			*string;
	int 		 	 flag;
	u_int			 locks;
	struct {
		struct fetch	*fetch;
		void		*data;
	} fetch;
	struct {
		char		*host;
		char		*port;
	} server;
	enum area	 	 area;
	enum exprop		 exprop;
	struct actitem 		*actitem;
	struct actlist 		*actlist;
	struct expr		*expr;
	struct expritem		*expritem;
	struct strings		*strings;
	struct replstrs		*replstrs;
	enum fetch_only		 only;
	struct {
		char		*path;
		enum fetch_only	 only;
	} poponly;
	struct {
		int		 flags;
		char		*str;
	} re;
	gid_t			 localgid;
	enum cmp		 cmp;
	struct rule		*rule;
	struct {
		char		*user;
		int		 user_netrc;
		char		*pass;
		int		 pass_netrc;
	} userpass;
	userfunction		 ufn;
	struct userfunctions    *ufns;
} YYSTYPE;
#endif /* !YYSTYPE_IS_DECLARED */
#line 171 "y.tab.c"

/* compatibility with bison */
#ifdef YYPARSE_PARAM
/* compatibility with FreeBSD */
# ifdef YYPARSE_PARAM_TYPE
#  define YYPARSE_DECL() yyparse(YYPARSE_PARAM_TYPE YYPARSE_PARAM)
# else
#  define YYPARSE_DECL() yyparse(void *YYPARSE_PARAM)
# endif
#else
# define YYPARSE_DECL() yyparse(void)
#endif

/* Parameters sent to lex. */
#ifdef YYLEX_PARAM
# define YYLEX_DECL() yylex(void *YYLEX_PARAM)
# define YYLEX yylex(YYLEX_PARAM)
#else
# define YYLEX_DECL() yylex(void)
# define YYLEX yylex()
#endif

/* Parameters sent to yyerror. */
#ifndef YYERROR_DECL
#define YYERROR_DECL() yyerror(const char *s)
#endif
#ifndef YYERROR_CALL
#define YYERROR_CALL(msg) yyerror(msg)
#endif

extern int YYPARSE_DECL();

#define TOKACCOUNT 257
#define TOKACCOUNTS 258
#define TOKACTION 259
#define TOKACTIONS 260
#define TOKADDHEADER 261
#define TOKADDTOCACHE 262
#define TOKAGE 263
#define TOKALL 264
#define TOKALLOWMANY 265
#define TOKAND 266
#define TOKANYNAME 267
#define TOKANYSIZE 268
#define TOKANYTYPE 269
#define TOKAPPEND 270
#define TOKATTACHMENT 271
#define TOKBODY 272
#define TOKBYTES 273
#define TOKCACHE 274
#define TOKCASE 275
#define TOKCMDUSER 276
#define TOKCOMPRESS 277
#define TOKCONTINUE 278
#define TOKCOUNT 279
#define TOKCOURIER 280
#define TOKDAYS 281
#define TOKDEFUSER 282
#define TOKDELTOOBIG 283
#define TOKDISABLED 284
#define TOKDOMAIN 285
#define TOKDOTLOCK 286
#define TOKDROP 287
#define TOKEQ 288
#define TOKEXEC 289
#define TOKEXPIRE 290
#define TOKFCNTL 291
#define TOKFILEGROUP 292
#define TOKFILEUMASK 293
#define TOKFLOCK 294
#define TOKFOLDER 295
#define TOKFOLDERS 296
#define TOKFROM 297
#define TOKGIGABYTES 298
#define TOKGROUP 299
#define TOKGROUPS 300
#define TOKHEADER 301
#define TOKHEADERS 302
#define TOKHOURS 303
#define TOKIMAP 304
#define TOKIMAPS 305
#define TOKIMPLACT 306
#define TOKIN 307
#define TOKINCACHE 308
#define TOKINVALID 309
#define TOKKEEP 310
#define TOKKEY 311
#define TOKKILOBYTES 312
#define TOKLOCKFILE 313
#define TOKLOCKTYPES 314
#define TOKLOOKUPORDER 315
#define TOKMAILDIR 316
#define TOKMAILDIRS 317
#define TOKMATCH 318
#define TOKMATCHED 319
#define TOKMAXSIZE 320
#define TOKMBOX 321
#define TOKMBOXES 322
#define TOKMEGABYTES 323
#define TOKMINUTES 324
#define TOKMONTHS 325
#define TOKNE 326
#define TOKNEWONLY 327
#define TOKNNTP 328
#define TOKNNTPS 329
#define TOKNOAPOP 330
#define TOKNOCRAMMD5 331
#define TOKNOCREATE 332
#define TOKNOLOGIN 333
#define TOKNONE 334
#define TOKNORECEIVED 335
#define TOKNOT 336
#define TOKNOTLS1 337
#define TOKNOUIDL 338
#define TOKNOVERIFY 339
#define TOKOLDONLY 340
#define TOKOR 341
#define TOKPARALLELACCOUNTS 342
#define TOKPASS 343
#define TOKPASSWD 344
#define TOKPIPE 345
#define TOKPOP3 346
#define TOKPOP3S 347
#define TOKPORT 348
#define TOKPROXY 349
#define TOKPURGEAFTER 350
#define TOKQUEUEHIGH 351
#define TOKQUEUELOW 352
#define TOKREMOVEFROMCACHE 353
#define TOKREMOVEHEADER 354
#define TOKREMOVEHEADERS 355
#define TOKRETURNS 356
#define TOKREWRITE 357
#define TOKSECONDS 358
#define TOKSERVER 359
#define TOKSET 360
#define TOKSIZE 361
#define TOKSMTP 362
#define TOKSTDIN 363
#define TOKSTDOUT 364
#define TOKSTRING 365
#define TOKSTRIPCHARACTERS 366
#define TOKTAG 367
#define TOKTAGGED 368
#define TOKTIMEOUT 369
#define TOKTO 370
#define TOKTOTALSIZE 371
#define TOKUNMATCHED 372
#define TOKUSER 373
#define TOKUSERS 374
#define TOKVALUE 375
#define TOKVERIFYCERTS 376
#define TOKWEEKS 377
#define TOKWRITE 378
#define TOKYEARS 379
#define NONE 380
#define NUMBER 381
#define STRING 382
#define STRMACRO 383
#define NUMMACRO 384
#define STRCOMMAND 385
#define NUMCOMMAND 386
#define YYERRCODE 256
static const short yylhs[] = {                           -1,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   78,
   78,   79,   79,   80,   80,   81,   81,   82,   82,   83,
   83,   84,   84,   85,   85,   55,   55,   56,   56,   51,
   51,   51,   52,   52,   33,   33,   33,   53,   54,   31,
   31,   31,   31,   31,   32,   32,   32,   32,   32,   32,
   32,   32,   35,   35,   77,   75,   75,   75,   75,   75,
   75,   75,   75,   75,   75,   75,   75,   75,   75,   75,
   75,   75,   75,   75,   75,   75,   75,   75,   75,   75,
   73,   73,   39,   39,   59,   59,   60,   60,   69,   69,
   70,   70,   41,   41,   61,   61,   62,   62,   64,   64,
   29,   29,   29,   30,   30,   30,   28,   28,   58,   58,
   43,   43,   43,   44,   44,   13,   13,   15,   15,   14,
   14,   48,   48,   47,   47,   49,   49,   50,   50,   18,
   18,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    2,    2,   72,
   72,   42,   42,   40,   40,   12,   12,    3,    3,    3,
    3,   34,   34,   45,   45,    5,    5,    6,    6,    4,
    4,   16,   16,   17,   17,   10,   10,    9,    9,    9,
    9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
    9,    9,    9,    9,    8,    8,    7,    7,   46,   46,
   46,   46,   76,   74,   65,   65,   57,   57,   63,   63,
   25,   25,   26,   26,   20,   20,   27,   27,   19,   19,
   21,   21,   36,   36,   22,   22,   23,   23,   24,   24,
   68,   68,   68,   68,   67,   66,   66,   38,   38,   37,
   37,   11,   11,   11,   11,   11,   11,   11,   11,   71,
};
static const short yylen[] = {                            2,
    0,    2,    2,    2,    2,    2,    2,    2,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    2,    1,    2,    0,    1,
    1,    1,    1,    3,    1,    1,    1,    1,    1,    1,
    2,    2,    2,    2,    1,    2,    2,    2,    2,    2,
    2,    2,    2,    0,    3,    3,    3,    3,    2,    2,
    3,    3,    3,    3,    3,    3,    3,    3,    2,    3,
    3,    3,    3,    2,    2,    3,    3,    3,    3,    3,
    3,    3,    2,    1,    2,    1,    2,    1,    1,    1,
    2,    1,    2,    4,    2,    4,    2,    4,    2,    4,
    1,    1,    1,    2,    1,    1,    1,    1,    0,    2,
    0,    2,    4,    2,    1,    1,    0,    1,    0,    1,
    0,    2,    2,    3,    2,    0,    2,    0,    2,    1,
    0,    2,    2,    2,    2,    1,    3,    3,    8,    4,
    1,    3,    4,    4,    1,    1,    1,    2,    1,    4,
    6,    2,    4,    2,    4,    0,    1,    0,    2,    2,
    2,    1,    0,    1,    0,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    2,    3,    2,
   10,    3,    4,    5,    5,    2,    2,    4,    3,    5,
    5,    5,    4,    4,    3,    2,    1,    2,    4,    6,
    3,    1,    1,    3,    0,    1,    0,    2,    2,    4,
    1,    0,    1,    0,    1,    0,    1,    0,    1,    0,
    1,    0,    1,    1,    1,    1,    1,    1,    1,    1,
    4,    0,    2,    2,    4,    1,    0,    3,    0,    1,
    0,    8,    6,    9,    6,    1,    1,    1,    8,    6,
};
static const short yydefred[] = {                         1,
    0,    0,    0,    0,    0,    0,    9,    0,    0,  203,
    2,    3,    4,    5,    6,    7,    8,   31,   32,   30,
   33,    0,    0,    0,    0,    0,  116,    0,    0,    0,
   60,    0,    0,   59,    0,    0,    0,    0,    0,    0,
    0,   75,   74,    0,    0,    0,    0,    0,    0,    0,
   69,    0,    0,    0,  120,    0,   12,   13,    0,    0,
    0,   55,  202,    0,  204,  176,  177,    0,    0,   14,
   15,    0,  178,    0,    0,  172,    0,  186,  173,    0,
    0,    0,  187,    0,  180,    0,  115,    0,    0,    0,
   76,   36,   37,   35,   77,  108,  107,   78,   80,   71,
   70,   58,  103,  101,  102,  106,  105,    0,   90,   89,
   92,    0,   56,    0,   67,   68,   73,   72,   65,   66,
    0,   64,    0,    0,   82,   34,    0,   10,   11,    0,
    0,  175,  146,  227,  228,  147,    0,    0,    0,   24,
   25,    0,    0,  141,    0,  174,    0,  150,    0,    0,
    0,  145,  136,    0,    0,    0,    0,   53,    0,    0,
    0,  196,  189,  166,  167,    0,    0,    0,    0,    0,
    0,  114,    0,    0,    0,    0,    0,    0,  179,    0,
    0,  104,   91,   41,   44,   42,   43,   49,   46,   47,
   51,   48,   50,   52,    0,   20,   21,   22,   23,  229,
  230,    0,  226,  246,    0,    0,    0,    0,  247,  248,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  149,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  157,  201,    0,    0,  195,  188,    0,    0,
    0,  168,  169,    0,  170,  171,    0,    0,  183,    0,
    0,    0,  159,  161,  160,    0,    0,    0,  118,  250,
    0,    0,    0,    0,   95,    0,   97,    0,    0,  137,
    0,  130,  138,    0,    0,    0,    0,    0,  142,  151,
  148,    0,    0,    0,    0,    0,  113,    0,    0,  199,
  192,  190,  191,    0,  184,    0,    0,  153,    0,    0,
    0,    0,    0,   88,    0,    0,    0,    0,    0,    0,
  124,    0,    0,  140,    0,  234,    0,   18,   19,    0,
    0,  155,   94,    0,    0,    0,    0,  236,    0,  223,
  224,    0,    0,  206,    0,    0,   16,   17,    0,    0,
   96,   87,   98,  123,  122,    0,    0,  219,    0,    0,
  200,  162,    0,    0,    0,    0,    0,  221,    0,  240,
    0,    0,   99,    0,    0,  209,  231,  211,    0,    0,
    0,  245,  243,  238,    0,    0,   86,    0,    0,    0,
  213,    0,  164,    0,  235,  217,    0,    0,  100,   85,
    0,  210,  215,  139,  181,  242,    0,  249,  244,
};
static const short yydgoto[] = {                          1,
  222,  223,  179,  244,  166,  246,   28,   68,   29,   69,
  205,  234,   30,   56,  260,  149,  150,  273,  349,  394,
  359,  206,  151,  208,  369,  382,  387,   95,  107,  108,
  113,  122,  114,  353,   62,  332,  361,  333,  285,  152,
  153,   85,   59,   86,  384,   65,  220,  311,  314,  277,
   21,   22,   87,  304,  270,  279,  320,  252,  378,  305,
  209,  210,  339,  334,  335,  327,  328,  284,  111,  112,
   11,   12,   13,   14,   15,   16,   17,  154,   60,   88,
  340,  336,  211,  212,  155,
};
static const short yysindex[] = {                         0,
  322, -202, -202, -202, -257, 3556,    0,   39,   42,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   63, -171, -291,   63, -169,    0,   29, -249, -173,
    0, -202, -202,    0, -168, -225, -234, -202, -235, -247,
 -221,    0,    0, -221, -202, -306, -221, -221, -202, -221,
    0, -202, -221, -202,    0, -291,    0,    0, 3153, -113,
 -221,    0,    0, -166,    0,    0,    0, -249, -257,    0,
    0,  -14,    0, -230, -202,    0, -202,    0,    0,    4,
 -202, -202,    0, -202,    0, -184,    0, -105,   63,   63,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -226,    0,    0,
    0, -247,    0, -144,    0,    0,    0,    0,    0,    0,
   63,    0, -262,   63,    0,    0,  963,    0,    0, -202,
 -202,    0,    0,    0,    0,    0, -202, -202, -202,    0,
    0, -202, -232,    0, -202,    0, 3501,    0, -202, -202,
 -232,    0,    0,  -99,  -73, -202,   63,    0, -153, 3004,
 -257,    0,    0,    0,    0, -221, -202,    4, -202,  -58,
    4,    0, -181, -221,  -43,   63,  -23, -228,    0, -202,
   63,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, -205,    0,    0,    0,    0,    0,
    0, -201,    0,    0, -155, -232, -232, -232,    0,    0,
  -69,   -5,  -13, -147,   63,  -38, -140,   63, -202, -139,
  -40,    0, 3282,   63,   63, -296, -202,   63, -202,   63,
 -109,   63,    0,    0, 3411, -153,    0,    0,   63, -221,
   63,    0,    0, -221,    0,    0, -221, -202,    0, -263,
 -202, -182,    0,    0,    0,  -91, -202, -202,    0,    0,
 -296, -296, -296, -202,    0, -202,    0, -202,   63,    0,
 -202,    0,    0, -202, -159, -202, -188, -202,    0,    0,
    0, -202, -202, -185,   28,   32,    0,   63, 3391,    0,
    0,    0,    0,   63,    0,   63,  150,    0, -179, -179,
 -269, -185, -149,    0,   44,   48,   63,   63,   63, -150,
    0,   63, -202,    0,   63,    0, -145,    0,    0, -148,
 -202,    0,    0, -153, -221, -202, -185,    0, -269,    0,
    0,  -78, -130,    0, -269,   16,    0,    0,  -72,   24,
    0,    0,    0,    0,    0,   63, -202,    0, -128,   63,
    0,    0,  160, -135, -269, -130, -202,    0, -148,    0,
 -148, -202,    0, -202, -202,    0,    0,    0, -114, -263,
 -202,    0,    0,    0, -118, -128,    0,   59, -148,   68,
    0, -116,    0,  181,    0,    0, -116, -114,    0,    0,
 -116,    0,    0,    0,    0,    0, -116,    0,    0,
};
static const short yyrindex[] = {                         0,
    0,    0,    0,    0, 2732,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    1, 2859, 3262,   86,    7,    0,  -93,  -53,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2924,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  -22, 2732,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, -117,    0,    0, 2132, 2599,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2644,    0,    0,
    0, 2654,    0, 2309,    0,    0,    0,    0,    0,    0,
 2687,    0, 2362, 2695,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3133,    0, 2727,    0,
 2732,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  340, -131,    0,    0,    0,
  356,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, -133,    0,    0,    0,    0,    0,
    0, -132,    0,    0, 2741,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1196, 1265,    0, 1334,    0,  983,
 1403,    0,    0, 1472, 1544,  405,    0, 1613,    0, 1682,
    0,   72,    0,    0,    0, 2727,    0,    0,  375,    0,
  487,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  595,  460, -123,    0,    0,    0,    0,    0, 1751,    0,
    0,    0,    0,    0,  178,    0, 1820,    0,    0,    0,
    0,    0,    0,  520,    0,    0,    0,   76,    0,    0,
    0,    0,    0,  794,    0, -127,    0,    0, 1012,    0,
 2378,  707,    0,    0,    0,    0, 1892, 1961, 2030,    0,
    0, 1055,    0,    0, 2099,    0,  293,    0,    0,  761,
    0,    0,    0, 2727,  184,    0, 2416,    0,  689,    0,
    0,    0, 2411,    0,  560,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2168,    0,    0,  872,  649,
    0,    0,    0,    0, 2573, 2580,    0,    0, 2445,    0,
 1274,    0,    0,    0,    0,    0,    0,    0, 1124,  199,
    0,    0,    0,    0, 2480, 2280,    0,    0, 2547,    0,
    0, 2240,    0,    0,    0,    0, 2587, 2559,    0,    0,
 2587,    0,    0,    0,    0,    0, 2587,    0,    0,
};
static const short yygindex[] = {                         0,
  -48,    9,    0,    0,  -37,    0,    0,    0,  -56,  177,
    0, -215,    0,    0,    0,  216,    0,    0, -272, -330,
 -108,    0,  120,    0, -126, -137,    0,    0,  141,    0,
 -152,  -52,  -21,    0,    0, -283, -103,  -75, -125,  189,
    0,    0,   17, -242,    0,    0,  -70,    0,    0,    0,
  201, 3070, 2806,   31,    0,    0,    0,    0, -106,   -1,
    0,    0,    0,    0,  -45,    0,    2,  -76,  175,    0,
    0,    0,    0,    0,    0,    0,    0,  235,    0,    0,
    0,   23,    0,    0,    0,
};
#define YYTABLESIZE 3932
static const short yytable[] = {                         54,
   38,  164,   54,  165,   54,  158,   54,  295,  158,  156,
  148,   75,  162,   96,   99,  287,   66,  180,  188,   54,
  290,  249,  115,  227,  118,  119,  120,  117,  123,   54,
  231,  125,  109,  298,   26,  253,  167,  168,  169,  123,
  189,   38,  174,  254,   64,  164,  282,  165,  170,  229,
  103,  360,  100,  264,  256,  104,  396,  330,  105,  103,
  398,  190,  191,  164,  104,  165,  399,  105,  102,  197,
  331,  360,  127,  255,   92,  101,  283,   93,   27,   94,
  226,   57,   58,   70,   71,   39,  375,  291,  376,   72,
   73,   67,  128,  129,  293,  192,  110,   74,  106,   52,
  198,   75,   53,  286,  237,   54,  391,  173,  351,  318,
  319,  236,   55,  238,  193,   76,  194,  266,   18,   19,
   61,   20,  178,   38,  233,   38,  219,  383,  184,  248,
  240,   54,  245,  247,   77,  261,  262,  263,  362,  257,
  171,  158,  158,  258,  123,   78,  365,   98,  158,  337,
  338,   63,  322,  185,  259,   92,  323,  276,   93,   92,
   94,  214,   93,  271,   94,  111,  111,  186,  341,  217,
  274,   79,  343,  297,  281,  232,  232,  125,  187,   18,
   19,  313,   20,  389,  301,  302,  303,   80,  310,  325,
  348,   81,  392,  326,   82,  357,   84,  347,   83,  358,
   83,  364,  368,  370,   91,  197,  197,  371,   18,   19,
   39,   20,   92,   18,   19,   93,   20,   94,  381,  386,
  393,  395,  292,  158,  109,  227,  225,  163,  110,  242,
   92,   18,   19,   93,   20,   94,  198,  198,  272,  165,
  281,  265,  267,  289,  161,   84,  207,  373,  182,  388,
  397,  372,  159,  356,  126,  158,  158,   38,  380,   38,
   38,   38,   38,   54,  306,   54,   38,  243,   18,   19,
   38,   20,   18,   19,   38,   20,   18,   19,   38,   20,
   54,  355,   18,   19,   38,   20,  183,   38,  344,   38,
   18,   19,  233,   20,  163,   38,   38,   38,  160,   38,
   38,  329,  125,  352,   38,   38,  321,   38,   18,   19,
   38,   20,   18,   19,    0,   20,   38,   38,   38,  197,
  197,   38,   38,    0,   54,    0,  250,   38,   38,   38,
   38,   38,    0,   38,  278,  342,  342,   38,   38,   38,
   38,   38,   39,   38,   39,   38,   38,   38,   38,  251,
  198,  198,    0,   38,   38,   38,    0,   38,    0,   39,
   38,  268,   38,   38,   38,    0,   54,   38,   18,   19,
   38,   20,    0,   38,   38,   39,   18,   19,   38,   20,
   38,    0,   38,   38,   38,   38,   54,  374,    0,   54,
   54,    0,    0,    0,  379,   39,   39,   18,   19,    0,
   20,   57,   58,   39,  232,   18,   19,    0,   20,   18,
   19,    0,   20,   18,   19,   39,   20,  233,    0,    0,
    0,    0,   39,   39,   39,   18,   19,    0,   20,   18,
   19,    0,   20,    0,  125,    0,  125,  125,  125,  125,
   18,   19,    0,   20,    0,   39,   10,  125,    0,   18,
   19,  125,   20,   84,   84,  125,   84,   83,   83,  232,
   83,    0,  182,    0,  125,   39,  125,   39,   39,   39,
   39,    0,  125,  125,  125,    0,  125,  125,  152,    0,
    0,  125,  125,    0,    0,    0,    0,  125,    0,    0,
    0,    0,    0,  125,    0,  125,    0,  194,  125,    0,
    0,    0,    0,    0,  125,    0,    0,  125,  125,    0,
  125,    0,    0,    0,  125,  125,  125,  125,    0,  207,
  125,    0,  125,    0,    0,    0,    0,    0,    0,  232,
  125,  125,  125,    0,  125,    0,    0,  125,    0,  125,
    0,  125,    0,    0,  125,    0,    0,  125,    0,  233,
  125,  233,  233,  233,  233,  125,    0,  125,    0,  241,
  125,  125,  233,    0,    0,    0,  233,    0,    0,    0,
  233,    0,    0,    0,    0,    0,    0,    0,    2,  233,
    3,  233,    0,    0,  232,    0,    0,  233,  233,    0,
    0,  233,  233,    0,  232,    4,  233,  233,  182,  182,
    0,    0,  233,    0,    0,  182,    0,    0,  233,  193,
  233,    0,    0,  233,  152,  152,    0,    0,    0,  233,
    0,  152,  233,  233,    0,  233,    0,    0,    0,  233,
  233,  233,  233,  194,  194,    0,    0,  233,    0,    5,
  194,    0,    0,    0,  207,  233,  233,  233,  208,  233,
    0,    0,  233,    0,  233,    0,  233,    0,    0,  233,
    0,  232,    0,  232,  232,  232,  232,    0,    0,    0,
  233,    0,  233,    0,  232,  233,  233,    0,  232,    0,
  182,    6,  232,    0,  241,    0,    0,    0,  239,    0,
    0,  232,    0,  232,    0,    0,  152,    0,    0,  232,
  232,    7,    0,    0,    8,    9,  205,    0,  232,  232,
    0,    0,  182,  182,  232,  194,  232,    0,  232,  232,
  232,    0,  232,    0,    0,  232,    0,    0,  152,  152,
    0,    0,    0,  232,    0,  232,    0,  232,    0,    0,
    0,  232,    0,  232,    0,  193,  193,  194,  194,  232,
    0,    0,  193,    0,  232,  232,    0,  232,  232,  232,
  220,  232,    0,    0,  232,    0,  232,    0,  232,  232,
    0,  232,    0,  208,    0,    0,  207,  232,  207,  207,
  207,  207,  232,    0,  232,    0,  232,  232,  232,  207,
  232,    0,  232,  207,    0,    0,  232,  207,  232,  232,
    0,    0,    0,    0,    0,    0,  207,    0,  207,    0,
    0,    0,    0,  239,    0,    0,  241,    0,  241,  232,
    0,    0,    0,  207,  207,    0,    0,  193,    0,  207,
    0,  205,    0,  241,    0,  207,    0,  207,    0,  232,
  207,    0,  232,  232,    0,    0,    0,    0,    0,    0,
  207,  232,  207,  232,    0,    0,  207,    0,  207,  193,
  193,    0,    0,    0,  207,    0,    0,    0,  232,  241,
    0,  212,  207,  207,  207,    0,  207,  241,    0,  207,
    0,  207,    0,  207,    0,  220,  207,    0,    0,    0,
  241,    0,  241,    0,    0,    0,  241,  207,  241,  207,
    0,    0,  207,  207,  232,  208,    0,  208,  208,  208,
  208,    0,  232,    0,    0,    0,  185,    0,  208,  241,
    0,  232,  208,    0,  232,    0,  208,    0,    0,    0,
    0,  232,  232,  232,  232,  208,    0,  208,    0,  241,
    0,    0,  241,  241,    0,  239,    0,  239,    0,    0,
    0,    0,  208,  208,  232,    0,    0,    0,  208,    0,
    0,    0,  239,  205,  208,  205,  208,    0,    0,  208,
    0,    0,    0,    0,  232,    0,    0,  232,  232,  208,
  205,  208,  128,    0,    0,  208,    0,  208,    0,    0,
    0,    0,    0,  208,    0,    0,  212,    0,  239,    0,
    0,  208,  208,  208,    0,  208,  239,    0,  208,    0,
  208,  237,  208,    0,    0,  208,  205,  220,  239,  220,
  220,  220,  220,    0,  205,    0,  208,    0,  208,    0,
  220,  208,  208,  205,  220,    0,    0,  205,  220,  205,
    0,    0,    0,  205,    0,  205,  205,  220,  239,  220,
    0,    0,  185,  185,  129,    0,    0,    0,    0,  185,
    0,    0,    0,    0,  220,  220,  205,    0,  239,    0,
  220,  239,  239,    0,    0,    0,  220,    0,  220,    0,
    0,  220,    0,    0,    0,    0,  205,    0,    0,  205,
  205,  220,    0,  220,    0,    0,    0,  220,    0,    0,
    0,    0,    0,    0,    0,  220,    0,  128,    0,    0,
    0,    0,    0,  220,  220,  220,    0,  220,    0,    0,
  220,    0,  220,  214,  220,    0,    0,  220,  212,    0,
  212,  212,  212,  212,  185,    0,  237,    0,  220,    0,
  220,  212,    0,  220,  220,  212,    0,    0,    0,  212,
    0,    0,    0,    0,    0,    0,    0,    0,  212,    0,
  212,    0,    0,    0,    0,    0,  185,  185,    0,    0,
    0,    0,    0,    0,    0,  212,  212,    0,    0,  129,
    0,  212,    0,    0,    0,    0,    0,  212,    0,  212,
    0,    0,  212,    0,    0,  135,    0,    0,    0,    0,
    0,    0,    0,    0,  212,    0,    0,    0,  212,    0,
    0,    0,    0,    0,    0,    0,  212,    0,    0,    0,
    0,    0,    0,    0,  212,  212,  212,    0,  212,    0,
    0,  212,    0,  212,    0,  212,    0,    0,  212,  128,
    0,  128,  128,  128,  128,    0,    0,    0,  214,  212,
    0,  212,  128,    0,  212,  212,  128,    0,    0,    0,
  128,    0,    0,    0,  131,    0,  195,  135,  237,  128,
  237,  128,    0,  220,    0,    0,    0,    0,  196,  197,
    0,    0,    0,  198,  199,  237,  128,  128,    0,    0,
  200,  201,  128,    0,    0,    0,    0,    0,  128,    0,
  128,    0,    0,  128,    0,    0,  237,  237,  202,  203,
    0,  129,    0,  129,  129,  129,  129,    0,    0,    0,
  135,  237,    0,    0,  129,  204,    0,  128,  129,  237,
    0,    0,  129,  133,    0,  128,  128,  128,  237,  128,
    0,  129,  128,  129,  128,    0,  128,    0,    0,  128,
    0,  237,  128,    0,    0,    0,    0,    0,  129,  129,
  128,    0,  128,    0,  129,  128,  128,    0,    0,    0,
  129,  237,  129,    0,    0,  129,    0,    0,    0,    0,
  214,    0,  214,  214,  214,  214,    0,    0,    0,  131,
    0,  237,    0,  214,  237,  237,    0,  214,  220,  129,
    0,  214,   29,    0,    0,    0,    0,  129,  129,  129,
  214,  129,  214,    0,  129,    0,  129,    0,  129,    0,
    0,  129,    0,    0,  129,    0,    0,  214,  214,    0,
    0,    0,  129,  214,  129,    0,    0,  129,  129,  214,
    0,  214,    0,    0,  214,    0,    0,    0,    0,    0,
    0,    0,  135,    0,  135,  135,  135,  135,  133,    0,
  214,    0,    0,    0,    0,  135,    0,    0,  214,  135,
    0,  132,    0,  135,    0,    0,  214,  214,  214,    0,
  214,    0,  135,  214,  135,  214,    0,  214,    0,    0,
  214,    0,    0,    0,    0,    0,    0,    0,    0,  135,
  135,  214,    0,  214,    0,  135,  214,  214,    0,    0,
    0,  135,    0,  135,    0,    0,  135,    0,    0,    0,
    0,  131,    0,  131,  131,  131,  131,   29,    0,    0,
  220,    0,  220,    0,  131,    0,    0,    0,  131,    0,
  135,    0,  131,  134,    0,    0,    0,  220,  135,  135,
  135,  131,  135,  131,    0,  135,    0,  135,    0,  135,
    0,    0,  135,    0,    0,    0,    0,    0,  131,  131,
    0,    0,    0,  135,  131,  135,    0,    0,  135,  135,
  131,    0,  131,  220,    0,  131,    0,    0,    0,    0,
  133,  220,  133,  133,  133,  133,  132,    0,    0,    0,
    0,    0,    0,  133,  220,    0,  220,  133,    0,  131,
  220,  133,  154,    0,    0,    0,    0,  131,  131,  131,
  133,  131,  133,    0,  131,    0,  131,    0,  131,    0,
    0,  131,    0,  220,    0,    0,    0,  133,  133,    0,
    0,    0,  131,  133,  131,    0,    0,  131,  131,  133,
    0,  133,    0,  220,  133,    0,  220,  220,    0,   29,
    0,   29,   29,   29,   29,    0,    0,    0,  134,    0,
    0,    0,   29,    0,    0,    0,   29,    0,  133,    0,
   29,   93,    0,    0,    0,    0,  133,  133,  133,   29,
  133,   29,    0,  133,    0,  133,    0,  133,    0,    0,
  133,    0,    0,    0,    0,    0,   29,   29,    0,    0,
    0,  133,   29,  133,    0,    0,  133,  133,   29,    0,
   29,    0,    0,   29,    0,    0,    0,    0,  132,    0,
  132,  132,  132,  132,    0,    0,    0,  154,    0,    0,
    0,  132,    0,    0,    0,  132,    0,   29,    0,  132,
   27,    0,    0,    0,    0,   29,   29,   29,  132,   29,
  132,    0,   29,    0,   29,    0,   29,    0,    0,   29,
    0,    0,    0,    0,    0,  132,  132,    0,    0,    0,
   29,  132,   29,    0,    0,   29,   29,  132,    0,  132,
    0,    0,  132,    0,    0,    0,    0,    0,    0,    0,
  134,    0,  134,  134,  134,  134,   93,    0,    0,    0,
    0,    0,    0,  134,    0,    0,  132,  134,    0,  126,
    0,  134,    0,    0,  132,  132,  132,    0,  132,    0,
  134,  132,  134,  132,    0,  132,    0,    0,  132,    0,
    0,    0,    0,    0,    0,    0,    0,  134,  134,  132,
    0,  132,    0,  134,  132,  132,    0,    0,    0,  134,
    0,  134,    0,    0,  134,    0,    0,    0,    0,  154,
    0,  154,  154,  154,  154,   27,    0,    0,    0,    0,
    0,    0,  154,    0,    0,    0,  154,    0,  134,    0,
  154,   26,    0,    0,    0,    0,  134,  134,  134,  154,
  134,  154,    0,  134,    0,  134,    0,  134,    0,    0,
  134,    0,    0,    0,    0,    0,  154,  154,    0,    0,
    0,  134,  154,  134,    0,    0,  134,  134,  154,    0,
  154,    0,    0,  154,    0,    0,    0,    0,   93,    0,
   93,   93,   93,   93,  126,    0,    0,    0,    0,    0,
    0,   93,    0,    0,    0,   93,    0,  154,    0,   93,
  143,    0,    0,    0,    0,  154,  154,  154,   93,  154,
   93,    0,  154,    0,  154,    0,  154,    0,    0,  154,
    0,    0,    0,    0,    0,   93,   93,    0,    0,    0,
  154,   93,  154,    0,    0,  154,  154,   93,    0,   93,
    0,    0,   93,    0,    0,    0,    0,   27,    0,   27,
   27,   27,   27,    0,    0,    0,   26,    0,    0,    0,
   27,    0,    0,    0,   27,    0,   93,    0,   27,  144,
    0,    0,    0,    0,   93,   93,   93,   27,   93,   27,
    0,   93,    0,   93,    0,   93,    0,    0,   93,    0,
    0,    0,    0,    0,   27,   27,    0,    0,    0,   93,
   27,   93,    0,    0,   93,   93,   27,    0,   27,    0,
    0,   27,    0,    0,    0,    0,  126,    0,  126,  126,
  126,  126,    0,    0,    0,  143,    0,    0,    0,  126,
    0,    0,    0,  126,    0,   27,    0,  126,   28,    0,
    0,    0,    0,   27,   27,   27,  126,   27,  126,    0,
   27,    0,   27,    0,   27,    0,    0,   27,    0,    0,
    0,    0,    0,  126,  126,    0,    0,    0,   27,  126,
   27,   62,    0,   27,   27,  126,    0,  126,    0,    0,
  126,    0,    0,    0,    0,    0,    0,    0,   26,    0,
   26,   26,   26,   26,  144,    0,    0,    0,    0,    0,
    0,   26,    0,    0,  126,   26,    0,  127,    0,   26,
    0,    0,  126,  126,  126,    0,  126,    0,   26,  126,
   26,  126,    0,  126,    0,    0,  126,    0,    0,    0,
    0,    0,    0,    0,    0,   26,   26,  126,    0,  126,
    0,   26,  126,  126,    0,    0,    0,   26,    0,   26,
    0,    0,   26,    0,    0,    0,    0,  143,    0,  143,
  143,  143,  143,   28,    0,    0,    0,    0,    0,    0,
  143,    0,    0,    0,  143,    0,   26,    0,  143,  216,
    0,    0,    0,    0,   26,   26,   26,  143,   26,  143,
    0,   26,    0,   26,    0,   26,   62,    0,   26,    0,
    0,    0,    0,    0,  143,  143,    0,    0,    0,   26,
  143,   26,    0,    0,   26,   26,  143,    0,  143,  212,
    0,  143,    0,    0,    0,    0,  144,    0,  144,  144,
  144,  144,  127,    0,    0,    0,    0,    0,    0,  144,
    0,    0,    0,  144,    0,  143,    0,  144,   40,    0,
    0,    0,    0,  143,  143,  143,  144,  143,  144,    0,
  143,    0,  143,    0,  143,    0,    0,  143,    0,    0,
    0,    0,    0,  144,  144,    0,    0,    0,  143,  144,
  143,    0,    0,  143,  143,  144,    0,  144,    0,    0,
  144,    0,    0,    0,    0,   28,    0,   28,   28,   28,
   28,   45,    0,    0,  216,    0,    0,    0,   28,    0,
    0,    0,   28,    0,  144,    0,   28,  239,    0,    0,
    0,    0,  144,  144,  144,   28,  144,   28,   62,  144,
   62,  144,    0,  144,    0,    0,  144,    0,    0,    0,
    0,    0,   28,   28,  212,   62,    0,  144,   28,  144,
  222,    0,  144,  144,   28,  205,   28,    0,    0,   28,
    0,    0,    0,    0,  127,    0,  127,  127,  127,  127,
    0,   40,    0,   40,    0,    0,    0,  127,    0,    0,
    0,  127,    0,   28,  220,  127,    0,    0,    0,   62,
    0,   28,   28,   28,  127,   28,  127,    0,   28,    0,
   28,    0,   28,    0,    0,   28,    0,    0,    0,    0,
    0,  127,  127,    0,    0,    0,   28,  127,   28,  218,
    0,   28,   28,  127,   45,  127,   45,    0,  127,    0,
    0,   62,    0,    0,    0,    0,  216,    0,  216,  216,
  216,  216,  239,    0,    0,    0,    0,    0,    0,  216,
    0,   62,  127,  216,   62,   62,    0,  216,    0,    0,
  127,  127,  127,    0,  127,    0,  216,  127,  216,  127,
    0,  127,    0,    0,  127,  222,  212,    0,  212,    0,
  205,    0,    0,  216,  216,  127,  220,  127,    0,  216,
  127,  127,    0,  212,    0,  216,    0,  216,  214,    0,
  216,    0,    0,    0,    0,   40,    0,   40,   40,  220,
    0,    0,  241,    0,   40,    0,    0,    0,    0,  222,
    0,    0,   40,    0,  216,    0,  216,    0,    0,  212,
    0,    0,  216,  216,  216,    0,  216,  212,   61,  216,
    0,  216,    0,  216,  218,    0,  216,    0,    0,    0,
    0,    0,  212,    0,    0,    0,  212,  216,   45,  216,
   45,   45,  216,  216,    0,    0,   40,   45,    0,    0,
    0,    0,    0,    0,  239,   45,  239,    0,    0,  212,
    0,    0,    0,   57,    0,    0,    0,    0,    0,   40,
    0,  239,    0,   79,    0,    0,    0,    0,    0,  212,
    0,    0,  212,  212,    0,    0,    0,  222,   40,  222,
    0,  220,  205,    0,  205,    0,    0,    0,    0,   45,
    0,   40,   40,  214,  222,    0,   63,  239,   40,  205,
    0,   40,   40,    0,   81,  239,    0,  241,    0,    0,
    0,  220,   45,  220,  222,    0,    0,  239,    0,    0,
    0,  216,    0,    0,  239,  239,  239,    0,  220,    0,
  222,   45,    0,   61,    0,  205,  156,    0,  222,    0,
    0,    0,    0,  205,   45,   45,  218,  239,  218,    0,
  119,   45,  205,    0,   45,   45,    0,  222,  222,  222,
    0,    0,    0,  218,  220,  205,    0,  239,    0,    0,
  239,  239,  220,    0,    0,    0,    0,    0,   57,    0,
  222,    0,    0,    0,    0,  205,    0,    0,   79,    0,
    0,  220,  220,    0,    0,    0,    0,    0,    0,  218,
  222,    0,    0,  222,  222,  205,    0,  218,  205,  205,
    0,    0,    0,  220,  220,  220,    0,   23,   24,    0,
    0,   63,    0,    0,    0,  214,  218,  214,    0,   81,
  220,    0,    0,    0,  220,    0,    0,  220,  220,  241,
    0,  241,  214,    0,    0,    0,  222,    0,  222,  218,
   97,    0,    0,  216,    0,  216,  241,    0,    0,    0,
  116,  156,    0,  222,    0,   61,  220,   61,    0,  218,
  216,    0,  218,  218,  220,  119,    0,    0,  214,    0,
    0,    0,   61,    0,    0,    0,  214,    0,    0,    0,
  172,    0,  241,  220,    0,    0,    0,    0,    0,  222,
  241,    0,    0,    0,    0,  214,  216,  222,    0,    0,
   57,    0,   57,    0,  216,    0,  220,    0,    0,    0,
   79,    0,   79,    0,    0,    0,   61,   57,  214,    0,
    0,    0,    0,    0,    0,    0,  220,   79,    0,  220,
  220,    0,  241,    0,    0,    0,    0,    0,  214,  222,
    0,  214,  214,   63,    0,   63,  216,    0,    0,    0,
    0,   81,  241,   81,    0,  241,  241,    0,   61,  222,
   63,   57,  222,  222,    0,    0,  216,    0,   81,  216,
  216,   79,    0,    0,    0,    0,    0,    0,   61,    0,
    0,   61,   61,  156,    0,  156,    0,    0,  117,  117,
    0,    0,    0,    0,  117,  117,    0,  119,    0,  119,
  156,    0,  117,   57,   63,    0,  117,    0,    0,    0,
    0,    0,   81,   79,  119,    0,    0,    0,    0,    0,
  117,    0,    0,   57,  275,    0,   57,   57,    0,    0,
    0,    0,    0,   79,    0,    0,   79,   79,    0,  117,
    0,    0,    0,    0,  156,    0,   63,    0,    0,    0,
  117,    0,    0,    0,   81,    0,    0,    0,  119,    0,
    0,    0,  299,  300,    0,    0,   63,    0,    0,   63,
   63,    0,    0,   25,   81,    0,  117,   81,   81,    0,
    0,    0,    0,    0,    0,    0,  156,  316,  317,    0,
    0,    0,  117,    0,    0,    0,  117,    0,    0,  117,
  119,   89,   90,  117,    0,    0,  156,   25,    0,  156,
  156,    0,    0,  117,  117,  345,  117,    0,  121,    0,
  119,  124,    0,  119,  119,    0,  235,    0,    0,  157,
    0,  354,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  363,    0,    0,    0,  366,   25,    0,    0,    0,
  175,  176,  367,  177,    0,    0,    0,  181,    0,    0,
    0,    0,  121,  121,    0,    0,    0,  377,    0,    0,
  377,    0,    0,    0,  121,  121,  385,    0,    0,  121,
  121,    0,    0,  390,    0,  390,  121,  121,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  213,
   25,    0,    0,    0,  121,  121,  215,  216,   25,    0,
    0,  218,    0,    0,  221,    0,    0,    0,  224,  225,
    0,  121,    0,  228,  230,  232,    0,  111,  111,  228,
    0,  121,  121,    0,    0,    0,  239,    0,  241,  111,
  111,    0,    0,    0,  111,  111,    0,    0,    0,  232,
    0,  111,  111,    0,    0,  112,    0,    0,    0,    0,
    0,    0,  128,  129,  130,  131,    0,    0,    0,  111,
  111,    0,    0,  132,    0,  147,    0,    0,    0,    0,
   25,   25,  269,    0,    0,    0,  111,    0,    0,    0,
  133,    0,   76,    0,    0,    0,  232,    0,  232,    0,
  288,    0,    0,    0,  232,    0,    0,  134,  135,    0,
    0,    0,    0,  136,    0,    0,    0,  294,    0,  137,
  296,    0,    0,    0,  138,  288,    0,    0,    0,    0,
    0,    0,    0,   25,    0,   25,    0,  307,    0,    0,
  308,    0,    0,  309,    0,  312,    0,  315,   79,    0,
    0,    0,    0,    0,  288,  288,  139,  140,  141,    0,
  142,    0,    0,    0,    0,  143,    0,  144,    0,    0,
  145,    0,    0,    0,   25,   25,    0,    0,    0,    0,
    0,  146,  346,    0,  111,   18,   19,    0,   20,    0,
  350,  112,  112,  112,  112,    0,    0,    0,    0,    0,
    0,    0,  112,    0,    0,    0,  280,    0,    0,    0,
    0,  128,  129,  130,  131,    0,    0,    0,    0,  112,
    0,  112,  132,    0,    0,    0,   25,    0,    0,    0,
    0,    0,    0,   25,    0,    0,  112,  112,    0,  133,
    0,   76,  112,    0,    0,    0,    0,    0,  112,  112,
    0,    0,    0,  112,  112,    0,  134,  135,    0,    0,
  112,  112,  136,    0,    0,    0,    0,    0,  137,    0,
    0,    0,    0,  138,    0,    0,    0,  112,  112,  112,
    0,    0,    0,    0,    0,  112,  112,  112,    0,  112,
    0,    0,    0,    0,  112,  112,  112,   79,    0,  112,
    0,    0,    0,    0,    0,  139,  140,  141,    0,  142,
  112,    0,    0,    0,  143,  324,  144,    0,    0,  145,
  111,  111,  111,  111,    0,    0,    0,    0,    0,    0,
  146,  111,    0,    0,    0,    0,    0,    0,    0,    0,
  128,  129,  130,  131,    0,    0,    0,    0,  111,    0,
  111,  132,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  111,  111,    0,  133,    0,
   76,  111,    0,    0,    0,    0,    0,  111,    0,    0,
    0,    0,  111,    0,    0,  134,  135,    0,    0,    0,
    0,  136,    0,    0,    0,    0,    0,  137,    0,    0,
    0,    0,  138,    0,    0,    0,  111,    0,    0,    0,
    0,    0,    0,    0,  111,  111,  111,    0,  111,    0,
    0,    0,    0,  111,    0,  111,   79,    0,  111,    0,
    0,    0,    0,    0,  139,  140,  141,    0,  142,  111,
    0,    0,    0,  143,    0,  144,    0,    0,  145,  128,
  129,  130,  131,    0,    0,    0,    0,    0,    0,  146,
  132,    0,    0,    0,    0,    0,    0,    0,    0,  128,
  129,  130,  131,    0,    0,    0,    0,  133,    0,   76,
  132,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  134,  135,    0,  133,    0,   76,
  136,    0,    0,    0,    0,    0,  137,    0,    0,    0,
    0,  138,    0,    0,  134,  135,    0,    0,    0,    0,
  136,    0,    0,    0,    0,    0,  137,    0,    0,    0,
    0,  138,    0,    0,    0,   79,    0,    0,    0,    0,
    0,    0,    0,  139,  140,  141,    0,  142,    0,    0,
    0,    0,  143,    0,  144,   79,    0,  145,    0,  128,
  129,  130,  131,  139,  140,  141,    0,  142,  146,    0,
  132,    0,  143,    0,  144,    0,    0,  145,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  133,  146,   76,
    0,    0,   18,   19,    0,   20,    0,    0,    0,    0,
    0,    0,    0,    0,  134,  135,    0,    0,    0,    0,
  136,    0,    0,    0,    0,    0,  137,    0,    0,    0,
   31,  138,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   32,    0,    0,    0,    0,    0,   33,   34,    0,
    0,    0,    0,    0,    0,   79,    0,   35,   36,    0,
    0,    0,    0,  139,  140,  141,    0,  142,    0,    0,
    0,   37,  143,    0,  144,    0,    0,  145,   38,   39,
   40,    0,    0,    0,    0,   41,    0,    0,  146,    0,
    0,    0,    0,    0,    0,    0,    0,   42,    0,    0,
   43,    0,    0,    0,    0,    0,    0,   44,    0,    0,
    0,    0,    0,    0,   45,   46,   47,   48,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   49,    0,    0,   50,    0,    0,    0,    0,    0,
    0,   51,
};
static const short yycheck[] = {                         43,
    0,   60,   43,   62,   43,  123,    0,  250,   61,  123,
   59,  275,   69,   35,   36,  125,  266,  123,  281,   43,
  236,  174,   44,  123,   46,   47,   48,  334,   50,   43,
  156,   53,  280,  125,    4,  264,  267,  268,  269,   61,
  303,   41,   80,  272,   28,   60,  343,   62,  279,  123,
  286,  335,  287,  123,  180,  291,  387,  327,  294,  286,
  391,  324,  325,   60,  291,   62,  397,  294,   38,  123,
  340,  355,   56,  302,  381,  310,  373,  384,  336,  386,
  151,  373,  374,  257,  258,    0,  359,  240,  361,  263,
  264,  341,  259,  260,  247,  358,  344,  271,  334,   61,
  123,  275,   61,  229,  161,   43,  379,   77,  324,  295,
  296,  160,  284,  166,  377,  289,  379,  123,  382,  383,
  290,  385,  307,  123,  278,  125,  359,  370,  273,  311,
  168,  125,  170,  171,  308,  206,  207,  208,  123,  345,
  371,  259,  260,  345,  166,  319,  123,  373,  266,  299,
  300,  123,  125,  298,  310,  381,  125,  297,  384,  381,
  386,  131,  384,  311,  386,  259,  260,  312,  125,  139,
  311,  345,  125,  356,  223,  299,  300,    0,  323,  382,
  383,  370,  385,  125,  261,  262,  263,  361,  348,   40,
  339,  365,  125,  373,  368,  274,  125,  343,  372,  330,
  125,  274,  331,   44,  373,  259,  260,  343,  382,  383,
  125,  385,  381,  382,  383,  384,  385,  386,  333,  338,
  337,   41,  244,  341,  356,  359,  359,   44,  356,  288,
  381,  382,  383,  384,  385,  386,  259,  260,  277,   41,
  289,  211,  212,  235,   68,   30,  127,  356,  108,  376,
  388,  355,   64,  329,   54,  373,  374,  257,  365,  259,
  260,  261,  262,  257,  266,  259,  266,  326,  382,  383,
  270,  385,  382,  383,  274,  385,  382,  383,  278,  385,
  274,  327,  382,  383,  284,  385,  112,  287,  310,  289,
  382,  383,    0,  385,  309,  295,  296,  297,   64,  299,
  300,  300,  125,  325,  304,  305,  284,  307,  382,  383,
  310,  385,  382,  383,   -1,  385,  316,  317,  318,  373,
  374,  321,  322,   -1,  318,   -1,  370,  327,  328,  329,
  330,  331,   -1,  333,  375,  305,  306,  337,  338,  339,
  340,  341,  257,  343,  259,  345,  346,  347,  348,  373,
  373,  374,   -1,  353,  354,  355,   -1,  357,   -1,  274,
  360,  375,  362,  363,  364,   -1,  360,  367,  382,  383,
  370,  385,   -1,  373,  374,  290,  382,  383,  378,  385,
  380,   -1,  382,  383,  384,  385,  380,  357,   -1,  383,
  384,   -1,   -1,   -1,  364,  310,  311,  382,  383,   -1,
  385,  373,  374,  318,    0,  382,  383,   -1,  385,  382,
  383,   -1,  385,  382,  383,  330,  385,  125,   -1,   -1,
   -1,   -1,  337,  338,  339,  382,  383,   -1,  385,  382,
  383,   -1,  385,   -1,  257,   -1,  259,  260,  261,  262,
  382,  383,   -1,  385,   -1,  360,  125,  270,   -1,  382,
  383,  274,  385,  382,  383,  278,  385,  382,  383,    0,
  385,   -1,  123,   -1,  287,  380,  289,  382,  383,  384,
  385,   -1,  295,  296,  297,   -1,  299,  300,  123,   -1,
   -1,  304,  305,   -1,   -1,   -1,   -1,  310,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,   -1,  123,  321,   -1,
   -1,   -1,   -1,   -1,  327,   -1,   -1,  330,  331,   -1,
  333,   -1,   -1,   -1,  337,  338,  339,  340,   -1,    0,
  343,   -1,  345,   -1,   -1,   -1,   -1,   -1,   -1,  125,
  353,  354,  355,   -1,  357,   -1,   -1,  360,   -1,  362,
   -1,  364,   -1,   -1,  367,   -1,   -1,  370,   -1,  257,
  373,  259,  260,  261,  262,  378,   -1,  380,   -1,    0,
  383,  384,  270,   -1,   -1,   -1,  274,   -1,   -1,   -1,
  278,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,  287,
  259,  289,   -1,   -1,  125,   -1,   -1,  295,  296,   -1,
   -1,  299,  300,   -1,    0,  274,  304,  305,  259,  260,
   -1,   -1,  310,   -1,   -1,  266,   -1,   -1,  316,  123,
  318,   -1,   -1,  321,  259,  260,   -1,   -1,   -1,  327,
   -1,  266,  330,  331,   -1,  333,   -1,   -1,   -1,  337,
  338,  339,  340,  259,  260,   -1,   -1,  345,   -1,  318,
  266,   -1,   -1,   -1,  125,  353,  354,  355,    0,  357,
   -1,   -1,  360,   -1,  362,   -1,  364,   -1,   -1,  367,
   -1,  257,   -1,  259,  260,  261,  262,   -1,   -1,   -1,
  378,   -1,  380,   -1,  270,  383,  384,   -1,  274,   -1,
  341,  360,  278,   -1,  125,   -1,   -1,   -1,    0,   -1,
   -1,  287,   -1,  289,   -1,   -1,  341,   -1,   -1,  295,
  296,  380,   -1,   -1,  383,  384,    0,   -1,  304,  305,
   -1,   -1,  373,  374,  310,  341,  257,   -1,  259,  125,
  316,   -1,  318,   -1,   -1,  321,   -1,   -1,  373,  374,
   -1,   -1,   -1,  274,   -1,  331,   -1,  333,   -1,   -1,
   -1,  337,   -1,  339,   -1,  259,  260,  373,  374,  345,
   -1,   -1,  266,   -1,  295,  296,   -1,  353,  354,  355,
    0,  357,   -1,   -1,  360,   -1,  362,   -1,  364,  310,
   -1,  367,   -1,  125,   -1,   -1,  257,  318,  259,  260,
  261,  262,  378,   -1,  380,   -1,  327,  383,  384,  270,
  331,   -1,  333,  274,   -1,   -1,  337,  278,  339,  340,
   -1,   -1,   -1,   -1,   -1,   -1,  287,   -1,  289,   -1,
   -1,   -1,   -1,  125,   -1,   -1,  257,   -1,  259,  360,
   -1,   -1,   -1,  304,  305,   -1,   -1,  341,   -1,  310,
   -1,  125,   -1,  274,   -1,  316,   -1,  318,   -1,  380,
  321,   -1,  383,  384,   -1,   -1,   -1,   -1,   -1,   -1,
  331,  257,  333,  259,   -1,   -1,  337,   -1,  339,  373,
  374,   -1,   -1,   -1,  345,   -1,   -1,   -1,  274,  310,
   -1,    0,  353,  354,  355,   -1,  357,  318,   -1,  360,
   -1,  362,   -1,  364,   -1,  125,  367,   -1,   -1,   -1,
  331,   -1,  333,   -1,   -1,   -1,  337,  378,  339,  380,
   -1,   -1,  383,  384,  310,  257,   -1,  259,  260,  261,
  262,   -1,  318,   -1,   -1,   -1,  123,   -1,  270,  360,
   -1,  327,  274,   -1,  330,   -1,  278,   -1,   -1,   -1,
   -1,  337,  338,  339,  340,  287,   -1,  289,   -1,  380,
   -1,   -1,  383,  384,   -1,  257,   -1,  259,   -1,   -1,
   -1,   -1,  304,  305,  360,   -1,   -1,   -1,  310,   -1,
   -1,   -1,  274,  257,  316,  259,  318,   -1,   -1,  321,
   -1,   -1,   -1,   -1,  380,   -1,   -1,  383,  384,  331,
  274,  333,    0,   -1,   -1,  337,   -1,  339,   -1,   -1,
   -1,   -1,   -1,  345,   -1,   -1,  125,   -1,  310,   -1,
   -1,  353,  354,  355,   -1,  357,  318,   -1,  360,   -1,
  362,    0,  364,   -1,   -1,  367,  310,  257,  330,  259,
  260,  261,  262,   -1,  318,   -1,  378,   -1,  380,   -1,
  270,  383,  384,  327,  274,   -1,   -1,  331,  278,  333,
   -1,   -1,   -1,  337,   -1,  339,  340,  287,  360,  289,
   -1,   -1,  259,  260,    0,   -1,   -1,   -1,   -1,  266,
   -1,   -1,   -1,   -1,  304,  305,  360,   -1,  380,   -1,
  310,  383,  384,   -1,   -1,   -1,  316,   -1,  318,   -1,
   -1,  321,   -1,   -1,   -1,   -1,  380,   -1,   -1,  383,
  384,  331,   -1,  333,   -1,   -1,   -1,  337,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  345,   -1,  125,   -1,   -1,
   -1,   -1,   -1,  353,  354,  355,   -1,  357,   -1,   -1,
  360,   -1,  362,    0,  364,   -1,   -1,  367,  257,   -1,
  259,  260,  261,  262,  341,   -1,  125,   -1,  378,   -1,
  380,  270,   -1,  383,  384,  274,   -1,   -1,   -1,  278,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  287,   -1,
  289,   -1,   -1,   -1,   -1,   -1,  373,  374,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,  125,
   -1,  310,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,
   -1,   -1,  321,   -1,   -1,    0,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,  337,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  345,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  353,  354,  355,   -1,  357,   -1,
   -1,  360,   -1,  362,   -1,  364,   -1,   -1,  367,  257,
   -1,  259,  260,  261,  262,   -1,   -1,   -1,  125,  378,
   -1,  380,  270,   -1,  383,  384,  274,   -1,   -1,   -1,
  278,   -1,   -1,   -1,    0,   -1,  304,  305,  257,  287,
  259,  289,   -1,    0,   -1,   -1,   -1,   -1,  316,  317,
   -1,   -1,   -1,  321,  322,  274,  304,  305,   -1,   -1,
  328,  329,  310,   -1,   -1,   -1,   -1,   -1,  316,   -1,
  318,   -1,   -1,  321,   -1,   -1,  295,  296,  346,  347,
   -1,  257,   -1,  259,  260,  261,  262,   -1,   -1,   -1,
  125,  310,   -1,   -1,  270,  363,   -1,  345,  274,  318,
   -1,   -1,  278,    0,   -1,  353,  354,  355,  327,  357,
   -1,  287,  360,  289,  362,   -1,  364,   -1,   -1,  367,
   -1,  340,  370,   -1,   -1,   -1,   -1,   -1,  304,  305,
  378,   -1,  380,   -1,  310,  383,  384,   -1,   -1,   -1,
  316,  360,  318,   -1,   -1,  321,   -1,   -1,   -1,   -1,
  257,   -1,  259,  260,  261,  262,   -1,   -1,   -1,  125,
   -1,  380,   -1,  270,  383,  384,   -1,  274,  125,  345,
   -1,  278,    0,   -1,   -1,   -1,   -1,  353,  354,  355,
  287,  357,  289,   -1,  360,   -1,  362,   -1,  364,   -1,
   -1,  367,   -1,   -1,  370,   -1,   -1,  304,  305,   -1,
   -1,   -1,  378,  310,  380,   -1,   -1,  383,  384,  316,
   -1,  318,   -1,   -1,  321,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,  260,  261,  262,  125,   -1,
  337,   -1,   -1,   -1,   -1,  270,   -1,   -1,  345,  274,
   -1,    0,   -1,  278,   -1,   -1,  353,  354,  355,   -1,
  357,   -1,  287,  360,  289,  362,   -1,  364,   -1,   -1,
  367,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  304,
  305,  378,   -1,  380,   -1,  310,  383,  384,   -1,   -1,
   -1,  316,   -1,  318,   -1,   -1,  321,   -1,   -1,   -1,
   -1,  257,   -1,  259,  260,  261,  262,  125,   -1,   -1,
  257,   -1,  259,   -1,  270,   -1,   -1,   -1,  274,   -1,
  345,   -1,  278,    0,   -1,   -1,   -1,  274,  353,  354,
  355,  287,  357,  289,   -1,  360,   -1,  362,   -1,  364,
   -1,   -1,  367,   -1,   -1,   -1,   -1,   -1,  304,  305,
   -1,   -1,   -1,  378,  310,  380,   -1,   -1,  383,  384,
  316,   -1,  318,  310,   -1,  321,   -1,   -1,   -1,   -1,
  257,  318,  259,  260,  261,  262,  125,   -1,   -1,   -1,
   -1,   -1,   -1,  270,  331,   -1,  333,  274,   -1,  345,
  337,  278,    0,   -1,   -1,   -1,   -1,  353,  354,  355,
  287,  357,  289,   -1,  360,   -1,  362,   -1,  364,   -1,
   -1,  367,   -1,  360,   -1,   -1,   -1,  304,  305,   -1,
   -1,   -1,  378,  310,  380,   -1,   -1,  383,  384,  316,
   -1,  318,   -1,  380,  321,   -1,  383,  384,   -1,  257,
   -1,  259,  260,  261,  262,   -1,   -1,   -1,  125,   -1,
   -1,   -1,  270,   -1,   -1,   -1,  274,   -1,  345,   -1,
  278,    0,   -1,   -1,   -1,   -1,  353,  354,  355,  287,
  357,  289,   -1,  360,   -1,  362,   -1,  364,   -1,   -1,
  367,   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,
   -1,  378,  310,  380,   -1,   -1,  383,  384,  316,   -1,
  318,   -1,   -1,  321,   -1,   -1,   -1,   -1,  257,   -1,
  259,  260,  261,  262,   -1,   -1,   -1,  125,   -1,   -1,
   -1,  270,   -1,   -1,   -1,  274,   -1,  345,   -1,  278,
    0,   -1,   -1,   -1,   -1,  353,  354,  355,  287,  357,
  289,   -1,  360,   -1,  362,   -1,  364,   -1,   -1,  367,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
  378,  310,  380,   -1,   -1,  383,  384,  316,   -1,  318,
   -1,   -1,  321,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,  260,  261,  262,  125,   -1,   -1,   -1,
   -1,   -1,   -1,  270,   -1,   -1,  345,  274,   -1,    0,
   -1,  278,   -1,   -1,  353,  354,  355,   -1,  357,   -1,
  287,  360,  289,  362,   -1,  364,   -1,   -1,  367,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  304,  305,  378,
   -1,  380,   -1,  310,  383,  384,   -1,   -1,   -1,  316,
   -1,  318,   -1,   -1,  321,   -1,   -1,   -1,   -1,  257,
   -1,  259,  260,  261,  262,  125,   -1,   -1,   -1,   -1,
   -1,   -1,  270,   -1,   -1,   -1,  274,   -1,  345,   -1,
  278,    0,   -1,   -1,   -1,   -1,  353,  354,  355,  287,
  357,  289,   -1,  360,   -1,  362,   -1,  364,   -1,   -1,
  367,   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,
   -1,  378,  310,  380,   -1,   -1,  383,  384,  316,   -1,
  318,   -1,   -1,  321,   -1,   -1,   -1,   -1,  257,   -1,
  259,  260,  261,  262,  125,   -1,   -1,   -1,   -1,   -1,
   -1,  270,   -1,   -1,   -1,  274,   -1,  345,   -1,  278,
    0,   -1,   -1,   -1,   -1,  353,  354,  355,  287,  357,
  289,   -1,  360,   -1,  362,   -1,  364,   -1,   -1,  367,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
  378,  310,  380,   -1,   -1,  383,  384,  316,   -1,  318,
   -1,   -1,  321,   -1,   -1,   -1,   -1,  257,   -1,  259,
  260,  261,  262,   -1,   -1,   -1,  125,   -1,   -1,   -1,
  270,   -1,   -1,   -1,  274,   -1,  345,   -1,  278,    0,
   -1,   -1,   -1,   -1,  353,  354,  355,  287,  357,  289,
   -1,  360,   -1,  362,   -1,  364,   -1,   -1,  367,   -1,
   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,  378,
  310,  380,   -1,   -1,  383,  384,  316,   -1,  318,   -1,
   -1,  321,   -1,   -1,   -1,   -1,  257,   -1,  259,  260,
  261,  262,   -1,   -1,   -1,  125,   -1,   -1,   -1,  270,
   -1,   -1,   -1,  274,   -1,  345,   -1,  278,    0,   -1,
   -1,   -1,   -1,  353,  354,  355,  287,  357,  289,   -1,
  360,   -1,  362,   -1,  364,   -1,   -1,  367,   -1,   -1,
   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,  378,  310,
  380,    0,   -1,  383,  384,  316,   -1,  318,   -1,   -1,
  321,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,  260,  261,  262,  125,   -1,   -1,   -1,   -1,   -1,
   -1,  270,   -1,   -1,  345,  274,   -1,    0,   -1,  278,
   -1,   -1,  353,  354,  355,   -1,  357,   -1,  287,  360,
  289,  362,   -1,  364,   -1,   -1,  367,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,  378,   -1,  380,
   -1,  310,  383,  384,   -1,   -1,   -1,  316,   -1,  318,
   -1,   -1,  321,   -1,   -1,   -1,   -1,  257,   -1,  259,
  260,  261,  262,  125,   -1,   -1,   -1,   -1,   -1,   -1,
  270,   -1,   -1,   -1,  274,   -1,  345,   -1,  278,    0,
   -1,   -1,   -1,   -1,  353,  354,  355,  287,  357,  289,
   -1,  360,   -1,  362,   -1,  364,  125,   -1,  367,   -1,
   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,  378,
  310,  380,   -1,   -1,  383,  384,  316,   -1,  318,    0,
   -1,  321,   -1,   -1,   -1,   -1,  257,   -1,  259,  260,
  261,  262,  125,   -1,   -1,   -1,   -1,   -1,   -1,  270,
   -1,   -1,   -1,  274,   -1,  345,   -1,  278,    0,   -1,
   -1,   -1,   -1,  353,  354,  355,  287,  357,  289,   -1,
  360,   -1,  362,   -1,  364,   -1,   -1,  367,   -1,   -1,
   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,  378,  310,
  380,   -1,   -1,  383,  384,  316,   -1,  318,   -1,   -1,
  321,   -1,   -1,   -1,   -1,  257,   -1,  259,  260,  261,
  262,    0,   -1,   -1,  125,   -1,   -1,   -1,  270,   -1,
   -1,   -1,  274,   -1,  345,   -1,  278,    0,   -1,   -1,
   -1,   -1,  353,  354,  355,  287,  357,  289,  257,  360,
  259,  362,   -1,  364,   -1,   -1,  367,   -1,   -1,   -1,
   -1,   -1,  304,  305,  125,  274,   -1,  378,  310,  380,
    0,   -1,  383,  384,  316,    0,  318,   -1,   -1,  321,
   -1,   -1,   -1,   -1,  257,   -1,  259,  260,  261,  262,
   -1,  123,   -1,  125,   -1,   -1,   -1,  270,   -1,   -1,
   -1,  274,   -1,  345,    0,  278,   -1,   -1,   -1,  318,
   -1,  353,  354,  355,  287,  357,  289,   -1,  360,   -1,
  362,   -1,  364,   -1,   -1,  367,   -1,   -1,   -1,   -1,
   -1,  304,  305,   -1,   -1,   -1,  378,  310,  380,    0,
   -1,  383,  384,  316,  123,  318,  125,   -1,  321,   -1,
   -1,  360,   -1,   -1,   -1,   -1,  257,   -1,  259,  260,
  261,  262,  125,   -1,   -1,   -1,   -1,   -1,   -1,  270,
   -1,  380,  345,  274,  383,  384,   -1,  278,   -1,   -1,
  353,  354,  355,   -1,  357,   -1,  287,  360,  289,  362,
   -1,  364,   -1,   -1,  367,  125,  257,   -1,  259,   -1,
  125,   -1,   -1,  304,  305,  378,    0,  380,   -1,  310,
  383,  384,   -1,  274,   -1,  316,   -1,  318,    0,   -1,
  321,   -1,   -1,   -1,   -1,  257,   -1,  259,  260,  125,
   -1,   -1,    0,   -1,  266,   -1,   -1,   -1,   -1,    0,
   -1,   -1,  274,   -1,  345,   -1,    0,   -1,   -1,  310,
   -1,   -1,  353,  354,  355,   -1,  357,  318,    0,  360,
   -1,  362,   -1,  364,  125,   -1,  367,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,  337,  378,  257,  380,
  259,  260,  383,  384,   -1,   -1,  318,  266,   -1,   -1,
   -1,   -1,   -1,   -1,  257,  274,  259,   -1,   -1,  360,
   -1,   -1,   -1,    0,   -1,   -1,   -1,   -1,   -1,  341,
   -1,  274,   -1,    0,   -1,   -1,   -1,   -1,   -1,  380,
   -1,   -1,  383,  384,   -1,   -1,   -1,  257,  360,  259,
   -1,  125,  257,   -1,  259,   -1,   -1,   -1,   -1,  318,
   -1,  373,  374,  125,  274,   -1,    0,  310,  380,  274,
   -1,  383,  384,   -1,    0,  318,   -1,  125,   -1,   -1,
   -1,  257,  341,  259,  125,   -1,   -1,  330,   -1,   -1,
   -1,  125,   -1,   -1,  337,  338,  339,   -1,  274,   -1,
  310,  360,   -1,  125,   -1,  310,    0,   -1,  318,   -1,
   -1,   -1,   -1,  318,  373,  374,  257,  360,  259,   -1,
    0,  380,  327,   -1,  383,  384,   -1,  337,  338,  339,
   -1,   -1,   -1,  274,  310,  340,   -1,  380,   -1,   -1,
  383,  384,  318,   -1,   -1,   -1,   -1,   -1,  125,   -1,
  360,   -1,   -1,   -1,   -1,  360,   -1,   -1,  125,   -1,
   -1,  337,  338,   -1,   -1,   -1,   -1,   -1,   -1,  310,
  380,   -1,   -1,  383,  384,  380,   -1,  318,  383,  384,
   -1,   -1,   -1,  257,  360,  259,   -1,    2,    3,   -1,
   -1,  125,   -1,   -1,   -1,  257,  337,  259,   -1,  125,
  274,   -1,   -1,   -1,  380,   -1,   -1,  383,  384,  257,
   -1,  259,  274,   -1,   -1,   -1,  257,   -1,  259,  360,
   35,   -1,   -1,  257,   -1,  259,  274,   -1,   -1,   -1,
   45,  125,   -1,  274,   -1,  257,  310,  259,   -1,  380,
  274,   -1,  383,  384,  318,  125,   -1,   -1,  310,   -1,
   -1,   -1,  274,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   75,   -1,  310,  337,   -1,   -1,   -1,   -1,   -1,  310,
  318,   -1,   -1,   -1,   -1,  337,  310,  318,   -1,   -1,
  257,   -1,  259,   -1,  318,   -1,  360,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,  318,  274,  360,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  380,  274,   -1,  383,
  384,   -1,  360,   -1,   -1,   -1,   -1,   -1,  380,  360,
   -1,  383,  384,  257,   -1,  259,  360,   -1,   -1,   -1,
   -1,  257,  380,  259,   -1,  383,  384,   -1,  360,  380,
  274,  318,  383,  384,   -1,   -1,  380,   -1,  274,  383,
  384,  318,   -1,   -1,   -1,   -1,   -1,   -1,  380,   -1,
   -1,  383,  384,  257,   -1,  259,   -1,   -1,  257,  258,
   -1,   -1,   -1,   -1,  263,  264,   -1,  257,   -1,  259,
  274,   -1,  271,  360,  318,   -1,  275,   -1,   -1,   -1,
   -1,   -1,  318,  360,  274,   -1,   -1,   -1,   -1,   -1,
  289,   -1,   -1,  380,  219,   -1,  383,  384,   -1,   -1,
   -1,   -1,   -1,  380,   -1,   -1,  383,  384,   -1,  308,
   -1,   -1,   -1,   -1,  318,   -1,  360,   -1,   -1,   -1,
  319,   -1,   -1,   -1,  360,   -1,   -1,   -1,  318,   -1,
   -1,   -1,  257,  258,   -1,   -1,  380,   -1,   -1,  383,
  384,   -1,   -1,    4,  380,   -1,  345,  383,  384,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  360,  282,  283,   -1,
   -1,   -1,  361,   -1,   -1,   -1,  365,   -1,   -1,  368,
  360,   32,   33,  372,   -1,   -1,  380,   38,   -1,  383,
  384,   -1,   -1,  382,  383,  310,  385,   -1,   49,   -1,
  380,   52,   -1,  383,  384,   -1,  123,   -1,   -1,   60,
   -1,  326,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  336,   -1,   -1,   -1,  340,   77,   -1,   -1,   -1,
   81,   82,  347,   84,   -1,   -1,   -1,   88,   -1,   -1,
   -1,   -1,  304,  305,   -1,   -1,   -1,  362,   -1,   -1,
  365,   -1,   -1,   -1,  316,  317,  371,   -1,   -1,  321,
  322,   -1,   -1,  378,   -1,  380,  328,  329,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  130,
  131,   -1,   -1,   -1,  346,  347,  137,  138,  139,   -1,
   -1,  142,   -1,   -1,  145,   -1,   -1,   -1,  149,  150,
   -1,  363,   -1,  154,  155,  156,   -1,  304,  305,  160,
   -1,  373,  374,   -1,   -1,   -1,  167,   -1,  169,  316,
  317,   -1,   -1,   -1,  321,  322,   -1,   -1,   -1,  180,
   -1,  328,  329,   -1,   -1,  123,   -1,   -1,   -1,   -1,
   -1,   -1,  259,  260,  261,  262,   -1,   -1,   -1,  346,
  347,   -1,   -1,  270,   -1,  123,   -1,   -1,   -1,   -1,
  211,  212,  213,   -1,   -1,   -1,  363,   -1,   -1,   -1,
  287,   -1,  289,   -1,   -1,   -1,  227,   -1,  229,   -1,
  231,   -1,   -1,   -1,  235,   -1,   -1,  304,  305,   -1,
   -1,   -1,   -1,  310,   -1,   -1,   -1,  248,   -1,  316,
  251,   -1,   -1,   -1,  321,  256,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  264,   -1,  266,   -1,  268,   -1,   -1,
  271,   -1,   -1,  274,   -1,  276,   -1,  278,  345,   -1,
   -1,   -1,   -1,   -1,  285,  286,  353,  354,  355,   -1,
  357,   -1,   -1,   -1,   -1,  362,   -1,  364,   -1,   -1,
  367,   -1,   -1,   -1,  305,  306,   -1,   -1,   -1,   -1,
   -1,  378,  313,   -1,  123,  382,  383,   -1,  385,   -1,
  321,  259,  260,  261,  262,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  270,   -1,   -1,   -1,  125,   -1,   -1,   -1,
   -1,  259,  260,  261,  262,   -1,   -1,   -1,   -1,  287,
   -1,  289,  270,   -1,   -1,   -1,  357,   -1,   -1,   -1,
   -1,   -1,   -1,  364,   -1,   -1,  304,  305,   -1,  287,
   -1,  289,  310,   -1,   -1,   -1,   -1,   -1,  316,  317,
   -1,   -1,   -1,  321,  322,   -1,  304,  305,   -1,   -1,
  328,  329,  310,   -1,   -1,   -1,   -1,   -1,  316,   -1,
   -1,   -1,   -1,  321,   -1,   -1,   -1,  345,  346,  347,
   -1,   -1,   -1,   -1,   -1,  353,  354,  355,   -1,  357,
   -1,   -1,   -1,   -1,  362,  363,  364,  345,   -1,  367,
   -1,   -1,   -1,   -1,   -1,  353,  354,  355,   -1,  357,
  378,   -1,   -1,   -1,  362,  125,  364,   -1,   -1,  367,
  259,  260,  261,  262,   -1,   -1,   -1,   -1,   -1,   -1,
  378,  270,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  259,  260,  261,  262,   -1,   -1,   -1,   -1,  287,   -1,
  289,  270,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,  287,   -1,
  289,  310,   -1,   -1,   -1,   -1,   -1,  316,   -1,   -1,
   -1,   -1,  321,   -1,   -1,  304,  305,   -1,   -1,   -1,
   -1,  310,   -1,   -1,   -1,   -1,   -1,  316,   -1,   -1,
   -1,   -1,  321,   -1,   -1,   -1,  345,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  353,  354,  355,   -1,  357,   -1,
   -1,   -1,   -1,  362,   -1,  364,  345,   -1,  367,   -1,
   -1,   -1,   -1,   -1,  353,  354,  355,   -1,  357,  378,
   -1,   -1,   -1,  362,   -1,  364,   -1,   -1,  367,  259,
  260,  261,  262,   -1,   -1,   -1,   -1,   -1,   -1,  378,
  270,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  259,
  260,  261,  262,   -1,   -1,   -1,   -1,  287,   -1,  289,
  270,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  304,  305,   -1,  287,   -1,  289,
  310,   -1,   -1,   -1,   -1,   -1,  316,   -1,   -1,   -1,
   -1,  321,   -1,   -1,  304,  305,   -1,   -1,   -1,   -1,
  310,   -1,   -1,   -1,   -1,   -1,  316,   -1,   -1,   -1,
   -1,  321,   -1,   -1,   -1,  345,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  353,  354,  355,   -1,  357,   -1,   -1,
   -1,   -1,  362,   -1,  364,  345,   -1,  367,   -1,  259,
  260,  261,  262,  353,  354,  355,   -1,  357,  378,   -1,
  270,   -1,  362,   -1,  364,   -1,   -1,  367,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  287,  378,  289,
   -1,   -1,  382,  383,   -1,  385,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,   -1,
  310,   -1,   -1,   -1,   -1,   -1,  316,   -1,   -1,   -1,
  265,  321,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  276,   -1,   -1,   -1,   -1,   -1,  282,  283,   -1,
   -1,   -1,   -1,   -1,   -1,  345,   -1,  292,  293,   -1,
   -1,   -1,   -1,  353,  354,  355,   -1,  357,   -1,   -1,
   -1,  306,  362,   -1,  364,   -1,   -1,  367,  313,  314,
  315,   -1,   -1,   -1,   -1,  320,   -1,   -1,  378,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  332,   -1,   -1,
  335,   -1,   -1,   -1,   -1,   -1,   -1,  342,   -1,   -1,
   -1,   -1,   -1,   -1,  349,  350,  351,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  366,   -1,   -1,  369,   -1,   -1,   -1,   -1,   -1,
   -1,  376,
};
#define YYFINAL 1
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 386
#if YYDEBUG
static const char *yyname[] = {

"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,"'('","')'",0,"'+'","','",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'<'","'='",
"'>'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'{'",0,"'}'",0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,"TOKACCOUNT","TOKACCOUNTS","TOKACTION","TOKACTIONS","TOKADDHEADER",
"TOKADDTOCACHE","TOKAGE","TOKALL","TOKALLOWMANY","TOKAND","TOKANYNAME",
"TOKANYSIZE","TOKANYTYPE","TOKAPPEND","TOKATTACHMENT","TOKBODY","TOKBYTES",
"TOKCACHE","TOKCASE","TOKCMDUSER","TOKCOMPRESS","TOKCONTINUE","TOKCOUNT",
"TOKCOURIER","TOKDAYS","TOKDEFUSER","TOKDELTOOBIG","TOKDISABLED","TOKDOMAIN",
"TOKDOTLOCK","TOKDROP","TOKEQ","TOKEXEC","TOKEXPIRE","TOKFCNTL","TOKFILEGROUP",
"TOKFILEUMASK","TOKFLOCK","TOKFOLDER","TOKFOLDERS","TOKFROM","TOKGIGABYTES",
"TOKGROUP","TOKGROUPS","TOKHEADER","TOKHEADERS","TOKHOURS","TOKIMAP","TOKIMAPS",
"TOKIMPLACT","TOKIN","TOKINCACHE","TOKINVALID","TOKKEEP","TOKKEY",
"TOKKILOBYTES","TOKLOCKFILE","TOKLOCKTYPES","TOKLOOKUPORDER","TOKMAILDIR",
"TOKMAILDIRS","TOKMATCH","TOKMATCHED","TOKMAXSIZE","TOKMBOX","TOKMBOXES",
"TOKMEGABYTES","TOKMINUTES","TOKMONTHS","TOKNE","TOKNEWONLY","TOKNNTP",
"TOKNNTPS","TOKNOAPOP","TOKNOCRAMMD5","TOKNOCREATE","TOKNOLOGIN","TOKNONE",
"TOKNORECEIVED","TOKNOT","TOKNOTLS1","TOKNOUIDL","TOKNOVERIFY","TOKOLDONLY",
"TOKOR","TOKPARALLELACCOUNTS","TOKPASS","TOKPASSWD","TOKPIPE","TOKPOP3",
"TOKPOP3S","TOKPORT","TOKPROXY","TOKPURGEAFTER","TOKQUEUEHIGH","TOKQUEUELOW",
"TOKREMOVEFROMCACHE","TOKREMOVEHEADER","TOKREMOVEHEADERS","TOKRETURNS",
"TOKREWRITE","TOKSECONDS","TOKSERVER","TOKSET","TOKSIZE","TOKSMTP","TOKSTDIN",
"TOKSTDOUT","TOKSTRING","TOKSTRIPCHARACTERS","TOKTAG","TOKTAGGED","TOKTIMEOUT",
"TOKTO","TOKTOTALSIZE","TOKUNMATCHED","TOKUSER","TOKUSERS","TOKVALUE",
"TOKVERIFYCERTS","TOKWEEKS","TOKWRITE","TOKYEARS","NONE","NUMBER","STRING",
"STRMACRO","NUMMACRO","STRCOMMAND","NUMCOMMAND",
};
static const char *yyrule[] = {
"$accept : cmds",
"cmds :",
"cmds : cmds account",
"cmds : cmds defaction",
"cmds : cmds defmacro",
"cmds : cmds rule",
"cmds : cmds set",
"cmds : cmds close",
"cmds : cmds cache",
"cmds : cmds NONE",
"actionp : TOKACTION",
"actionp : TOKACTIONS",
"userp : TOKUSER",
"userp : TOKUSERS",
"accountp : TOKACCOUNT",
"accountp : TOKACCOUNTS",
"groupp : TOKGROUP",
"groupp : TOKGROUPS",
"folderp : TOKFOLDER",
"folderp : TOKFOLDERS",
"maildirp : TOKMAILDIR",
"maildirp : TOKMAILDIRS",
"mboxp : TOKMBOX",
"mboxp : TOKMBOXES",
"rmheaderp : TOKREMOVEHEADER",
"rmheaderp : TOKREMOVEHEADERS",
"val : TOKVALUE strv",
"val : strv",
"optval : TOKVALUE strv",
"optval :",
"xstrv : STRCOMMAND",
"xstrv : STRING",
"xstrv : STRMACRO",
"strv : xstrv",
"strv : strv '+' xstrv",
"numv : NUMCOMMAND",
"numv : NUMBER",
"numv : NUMMACRO",
"replstrv : strv",
"replpathv : strv",
"size : numv",
"size : numv TOKBYTES",
"size : numv TOKKILOBYTES",
"size : numv TOKMEGABYTES",
"size : numv TOKGIGABYTES",
"time : numv",
"time : numv TOKHOURS",
"time : numv TOKMINUTES",
"time : numv TOKSECONDS",
"time : numv TOKDAYS",
"time : numv TOKWEEKS",
"time : numv TOKMONTHS",
"time : numv TOKYEARS",
"expire : TOKEXPIRE time",
"expire :",
"cache : TOKCACHE replpathv expire",
"set : TOKSET TOKMAXSIZE size",
"set : TOKSET TOKLOCKTYPES locklist",
"set : TOKSET TOKLOCKFILE replpathv",
"set : TOKSET TOKDELTOOBIG",
"set : TOKSET TOKALLOWMANY",
"set : TOKSET TOKDEFUSER strv",
"set : TOKSET TOKCMDUSER strv",
"set : TOKSET TOKSTRIPCHARACTERS strv",
"set : TOKSET TOKTIMEOUT time",
"set : TOKSET TOKQUEUEHIGH numv",
"set : TOKSET TOKQUEUELOW numv",
"set : TOKSET TOKPARALLELACCOUNTS numv",
"set : TOKSET TOKPROXY replstrv",
"set : TOKSET TOKVERIFYCERTS",
"set : TOKSET TOKIMPLACT TOKKEEP",
"set : TOKSET TOKIMPLACT TOKDROP",
"set : TOKSET TOKPURGEAFTER numv",
"set : TOKSET TOKPURGEAFTER TOKNONE",
"set : TOKSET TOKNORECEIVED",
"set : TOKSET TOKNOCREATE",
"set : TOKSET TOKFILEGROUP TOKUSER",
"set : TOKSET TOKFILEGROUP localgid",
"set : TOKSET TOKFILEUMASK TOKUSER",
"set : TOKSET TOKLOOKUPORDER ufnlist",
"set : TOKSET TOKFILEUMASK numv",
"defmacro : STRMACRO '=' strv",
"defmacro : NUMMACRO '=' numv",
"replstrslist : replstrslist strv",
"replstrslist : strv",
"stringslist : stringslist replstrv",
"stringslist : replstrv",
"pathslist : pathslist replpathv",
"pathslist : replpathv",
"ufn : TOKPASSWD",
"ufn : TOKCOURIER",
"ufnlist : ufnlist ufn",
"ufnlist : ufn",
"rmheaders : rmheaderp strv",
"rmheaders : rmheaderp '{' replstrslist '}'",
"maildirs : maildirp replpathv",
"maildirs : maildirp '{' pathslist '}'",
"mboxes : mboxp replpathv",
"mboxes : mboxp '{' pathslist '}'",
"folders : folderp replstrv",
"folders : folderp '{' stringslist '}'",
"lock : TOKFCNTL",
"lock : TOKFLOCK",
"lock : TOKDOTLOCK",
"locklist : locklist lock",
"locklist : lock",
"locklist : TOKNONE",
"localgid : replstrv",
"localgid : numv",
"user :",
"user : TOKUSER strv",
"users :",
"users : userp strv",
"users : userp '{' replstrslist '}'",
"casere : TOKCASE replstrv",
"casere : replstrv",
"not : TOKNOT",
"not :",
"keep : TOKKEEP",
"keep :",
"disabled : TOKDISABLED",
"disabled :",
"port : TOKPORT replstrv",
"port : TOKPORT numv",
"server : TOKSERVER replstrv port",
"server : TOKSERVER replstrv",
"to :",
"to : TOKTO strv",
"from :",
"from : TOKFROM strv",
"compress : TOKCOMPRESS",
"compress :",
"actitem : execpipe strv",
"actitem : TOKREWRITE strv",
"actitem : writeappend strv",
"actitem : TOKMAILDIR strv",
"actitem : rmheaders",
"actitem : TOKADDHEADER strv val",
"actitem : TOKMBOX strv compress",
"actitem : imaptype server userpassnetrc folder1 verify nocrammd5 nologin tls1",
"actitem : TOKSMTP server from to",
"actitem : TOKSTDOUT",
"actitem : TOKTAG strv optval",
"actitem : TOKADDTOCACHE replpathv TOKKEY strv",
"actitem : TOKREMOVEFROMCACHE replpathv TOKKEY strv",
"actitem : actions",
"actitem : TOKDROP",
"actitem : TOKKEEP",
"actlist : actlist actitem",
"actlist : actitem",
"defaction : TOKACTION replstrv users actitem",
"defaction : TOKACTION replstrv users '{' actlist '}'",
"accounts : accountp strv",
"accounts : accountp '{' replstrslist '}'",
"actions : actionp strv",
"actions : actionp '{' replstrslist '}'",
"cont :",
"cont : TOKCONTINUE",
"area :",
"area : TOKIN TOKALL",
"area : TOKIN TOKHEADERS",
"area : TOKIN TOKBODY",
"retrc : numv",
"retrc :",
"retre : casere",
"retre :",
"ltgt : '<'",
"ltgt : '>'",
"eqne : TOKEQ",
"eqne : TOKNE",
"cmp : ltgt",
"cmp : eqne",
"execpipe : TOKEXEC",
"execpipe : TOKPIPE",
"writeappend : TOKWRITE",
"writeappend : TOKAPPEND",
"exprop : TOKAND",
"exprop : TOKOR",
"expritem : not TOKALL",
"expritem : not casere area",
"expritem : not accounts",
"expritem : not execpipe strv user TOKRETURNS '(' retrc ',' retre ')'",
"expritem : not TOKTAGGED strv",
"expritem : not TOKSIZE ltgt size",
"expritem : not TOKSTRING strv TOKTO casere",
"expritem : not TOKINCACHE replpathv TOKKEY strv",
"expritem : not TOKMATCHED",
"expritem : not TOKUNMATCHED",
"expritem : not TOKAGE ltgt time",
"expritem : not TOKAGE TOKINVALID",
"expritem : not TOKATTACHMENT TOKCOUNT cmp numv",
"expritem : not TOKATTACHMENT TOKTOTALSIZE ltgt size",
"expritem : not TOKATTACHMENT TOKANYSIZE ltgt size",
"expritem : not TOKATTACHMENT TOKANYTYPE strv",
"expritem : not TOKATTACHMENT TOKANYNAME strv",
"exprlist : exprlist exprop expritem",
"exprlist : exprop expritem",
"expr : expritem",
"expr : expritem exprlist",
"perform : users actionp actitem cont",
"perform : users actionp '{' actlist '}' cont",
"perform : users actions cont",
"perform : '{'",
"close : '}'",
"rule : TOKMATCH expr perform",
"folderlist :",
"folderlist : folders",
"folder1 :",
"folder1 : folderp strv",
"groups : groupp replstrv",
"groups : groupp '{' stringslist '}'",
"nocrammd5 : TOKNOCRAMMD5",
"nocrammd5 :",
"nologin : TOKNOLOGIN",
"nologin :",
"tls1 : TOKNOTLS1",
"tls1 :",
"uidl : TOKNOUIDL",
"uidl :",
"verify : TOKNOVERIFY",
"verify :",
"apop : TOKNOAPOP",
"apop :",
"only : TOKNEWONLY",
"only : TOKOLDONLY",
"poptype : TOKPOP3",
"poptype : TOKPOP3S",
"imaptype : TOKIMAP",
"imaptype : TOKIMAPS",
"nntptype : TOKNNTP",
"nntptype : TOKNNTPS",
"userpassnetrc : TOKUSER replstrv TOKPASS replstrv",
"userpassnetrc :",
"userpassnetrc : TOKUSER replstrv",
"userpassnetrc : TOKPASS replstrv",
"userpassreqd : TOKUSER replstrv TOKPASS replstrv",
"userpass : userpassreqd",
"userpass :",
"poponly : only TOKCACHE replpathv",
"poponly :",
"imaponly : only",
"imaponly :",
"fetchtype : poptype server userpassnetrc poponly apop verify uidl tls1",
"fetchtype : TOKPOP3 TOKPIPE replstrv userpassreqd poponly apop",
"fetchtype : imaptype server userpassnetrc folderlist imaponly verify nocrammd5 nologin tls1",
"fetchtype : TOKIMAP TOKPIPE replstrv userpass folderlist imaponly",
"fetchtype : TOKSTDIN",
"fetchtype : maildirs",
"fetchtype : mboxes",
"fetchtype : nntptype server userpassnetrc groups TOKCACHE replpathv verify tls1",
"account : TOKACCOUNT replstrv disabled users fetchtype keep",

};
#endif

int      yydebug;
int      yynerrs;

int      yyerrflag;
int      yychar;
YYSTYPE  yyval;
YYSTYPE  yylval;

/* define the initial stack-sizes */
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH  YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH  10000
#endif
#endif

#define YYINITSTACKSIZE 200

typedef struct {
    unsigned stacksize;
    short    *s_base;
    short    *s_mark;
    short    *s_last;
    YYSTYPE  *l_base;
    YYSTYPE  *l_mark;
} YYSTACKDATA;
/* variables for the parser stack */
static YYSTACKDATA yystack;
#line 2641 "parse.y"

/* Programs */
#line 1660 "y.tab.c"

#if YYDEBUG
#include <stdio.h>		/* needed for printf */
#endif

#include <stdlib.h>	/* needed for malloc, etc */
#include <string.h>	/* needed for memset */

/* allocate initial stack or double stack size, up to YYMAXDEPTH */
static int yygrowstack(YYSTACKDATA *data)
{
    int i;
    unsigned newsize;
    short *newss;
    YYSTYPE *newvs;

    if ((newsize = data->stacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return -1;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;

    i = (int) (data->s_mark - data->s_base);
    newss = (short *)realloc(data->s_base, newsize * sizeof(*newss));
    if (newss == 0)
        return -1;

    data->s_base = newss;
    data->s_mark = newss + i;

    newvs = (YYSTYPE *)realloc(data->l_base, newsize * sizeof(*newvs));
    if (newvs == 0)
        return -1;

    data->l_base = newvs;
    data->l_mark = newvs + i;

    data->stacksize = newsize;
    data->s_last = data->s_base + newsize - 1;
    return 0;
}

#if YYPURE || defined(YY_NO_LEAKS)
static void yyfreestack(YYSTACKDATA *data)
{
    free(data->s_base);
    free(data->l_base);
    memset(data, 0, sizeof(*data));
}
#else
#define yyfreestack(data) /* nothing */
#endif

#define YYABORT  goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR  goto yyerrlab

int
YYPARSE_DECL()
{
    int yym, yyn, yystate;
#if YYDEBUG
    const char *yys;

    if ((yys = getenv("YYDEBUG")) != 0)
    {
        yyn = *yys;
        if (yyn >= '0' && yyn <= '9')
            yydebug = yyn - '0';
    }
#endif

    yynerrs = 0;
    yyerrflag = 0;
    yychar = YYEMPTY;
    yystate = 0;

#if YYPURE
    memset(&yystack, 0, sizeof(yystack));
#endif

    if (yystack.s_base == NULL && yygrowstack(&yystack)) goto yyoverflow;
    yystack.s_mark = yystack.s_base;
    yystack.l_mark = yystack.l_base;
    yystate = 0;
    *yystack.s_mark = 0;

yyloop:
    if ((yyn = yydefred[yystate]) != 0) goto yyreduce;
    if (yychar < 0)
    {
        if ((yychar = YYLEX) < 0) yychar = 0;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, reading %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
    }
    if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: state %d, shifting to state %d\n",
                    YYPREFIX, yystate, yytable[yyn]);
#endif
        if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
        {
            goto yyoverflow;
        }
        yystate = yytable[yyn];
        *++yystack.s_mark = yytable[yyn];
        *++yystack.l_mark = yylval;
        yychar = YYEMPTY;
        if (yyerrflag > 0)  --yyerrflag;
        goto yyloop;
    }
    if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag) goto yyinrecovery;

    yyerror("syntax error");

    goto yyerrlab;

yyerrlab:
    ++yynerrs;

yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if ((yyn = yysindex[*yystack.s_mark]) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: state %d, error recovery shifting\
 to state %d\n", YYPREFIX, *yystack.s_mark, yytable[yyn]);
#endif
                if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
                {
                    goto yyoverflow;
                }
                yystate = yytable[yyn];
                *++yystack.s_mark = yytable[yyn];
                *++yystack.l_mark = yylval;
                goto yyloop;
            }
            else
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: error recovery discarding state %d\n",
                            YYPREFIX, *yystack.s_mark);
#endif
                if (yystack.s_mark <= yystack.s_base) goto yyabort;
                --yystack.s_mark;
                --yystack.l_mark;
            }
        }
    }
    else
    {
        if (yychar == 0) goto yyabort;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, error recovery discards token %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
        yychar = YYEMPTY;
        goto yyloop;
    }

yyreduce:
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: state %d, reducing by rule %d (%s)\n",
                YYPREFIX, yystate, yyn, yyrule[yyn]);
#endif
    yym = yylen[yyn];
    if (yym)
        yyval = yystack.l_mark[1-yym];
    else
        memset(&yyval, 0, sizeof yyval);
    switch (yyn)
    {
case 26:
#line 367 "parse.y"
	{
	     yyval.string = yystack.l_mark[0].string;
     }
break;
case 27:
#line 372 "parse.y"
	{
	     yyval.string = yystack.l_mark[0].string;
     }
break;
case 28:
#line 379 "parse.y"
	{
		yyval.string = yystack.l_mark[0].string;
        }
break;
case 29:
#line 383 "parse.y"
	{
		yyval.string = NULL;
	}
break;
case 30:
#line 389 "parse.y"
	{
	       yyval.string = run_command(yystack.l_mark[0].string, parse_file->path);
	       xfree(yystack.l_mark[0].string);
       }
break;
case 31:
#line 394 "parse.y"
	{
	       yyval.string = yystack.l_mark[0].string;
       }
break;
case 32:
#line 398 "parse.y"
	{
	       struct macro	*macro;

	       if (strlen(yystack.l_mark[0].string) > MAXNAMESIZE)
		       yyerror("macro name too long: %s", yystack.l_mark[0].string);

	       if ((macro = find_macro(yystack.l_mark[0].string)) == NULL)
		       yyerror("undefined macro: %s", yystack.l_mark[0].string);
	       if (macro->type != MACRO_STRING)
		       yyerror("string macro expected: %s", yystack.l_mark[0].string);

	       yyval.string = xstrdup(macro->value.str);

	       xfree(yystack.l_mark[0].string);
       }
break;
case 33:
#line 417 "parse.y"
	{
	      yyval.string = yystack.l_mark[0].string;
      }
break;
case 34:
#line 422 "parse.y"
	{
	      size_t	size;

	      size = strlen(yystack.l_mark[-2].string) + strlen(yystack.l_mark[0].string) + 1;
	      yyval.string = xrealloc(yystack.l_mark[-2].string, 1, size);
	      strlcat(yyval.string, yystack.l_mark[0].string, size);
	      xfree(yystack.l_mark[0].string);
      }
break;
case 35:
#line 433 "parse.y"
	{
	      const char	*errstr;
	      char		*s;

	      s = run_command(yystack.l_mark[0].string, parse_file->path);

	      yyval.number = strtonum(s, 0, LLONG_MAX, &errstr);
	      if (errstr != NULL)
		      yyerror("number is %s", errstr);

	      xfree(s);

	      xfree(yystack.l_mark[0].string);
      }
break;
case 36:
#line 448 "parse.y"
	{
	      yyval.number = yystack.l_mark[0].number;
      }
break;
case 37:
#line 452 "parse.y"
	{
	      struct macro	*macro;

	      if (strlen(yystack.l_mark[0].string) > MAXNAMESIZE)
		      yyerror("macro name too long: %s", yystack.l_mark[0].string);

	      if ((macro = find_macro(yystack.l_mark[0].string)) == NULL)
		      yyerror("undefined macro: %s", yystack.l_mark[0].string);
	      if (macro->type != MACRO_NUMBER)
		      yyerror("number macro expected: %s", yystack.l_mark[0].string);

	      yyval.number = macro->value.num;

	      xfree(yystack.l_mark[0].string);
      }
break;
case 38:
#line 471 "parse.y"
	{
		  struct replstr	rs;

		  rs.str = yystack.l_mark[0].string;
		  yyval.string = replacestr(&rs, parse_tags, NULL, NULL);
		  xfree(yystack.l_mark[0].string);
	  }
break;
case 39:
#line 482 "parse.y"
	{
		  struct replpath	rp;

		  rp.str = yystack.l_mark[0].string;
		  yyval.string = replacepath(&rp, parse_tags, NULL, NULL, conf.user_home);
		  xfree(yystack.l_mark[0].string);
	   }
break;
case 40:
#line 493 "parse.y"
	{
	      yyval.number = yystack.l_mark[0].number;
      }
break;
case 41:
#line 498 "parse.y"
	{
	      yyval.number = yystack.l_mark[-1].number;
      }
break;
case 42:
#line 503 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / 1024)
		      yyerror("size is too big");
	      yyval.number = yystack.l_mark[-1].number * 1024;
      }
break;
case 43:
#line 510 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / (1024 * 1024))
		      yyerror("size is too big");
	      yyval.number = yystack.l_mark[-1].number * (1024 * 1024);
      }
break;
case 44:
#line 517 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / (1024 * 1024 * 1024))
		      yyerror("size is too big");
	      yyval.number = yystack.l_mark[-1].number * (1024 * 1024 * 1024);
      }
break;
case 45:
#line 526 "parse.y"
	{
	      yyval.number = yystack.l_mark[0].number;
      }
break;
case 46:
#line 531 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_HOUR)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_HOUR;
      }
break;
case 47:
#line 538 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_MINUTE)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_MINUTE;
      }
break;
case 48:
#line 545 "parse.y"
	{
	      yyval.number = yystack.l_mark[-1].number;
      }
break;
case 49:
#line 550 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_DAY)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_DAY;
      }
break;
case 50:
#line 557 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_WEEK)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_WEEK;
      }
break;
case 51:
#line 564 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_MONTH)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_MONTH;
      }
break;
case 52:
#line 571 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_YEAR)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_YEAR;
      }
break;
case 53:
#line 580 "parse.y"
	{
#if UINT64_MAX < LLONG_MAX
		if (yystack.l_mark[0].number > UINT64_MAX)
			yyerror("time too long");
#endif

		yyval.number = yystack.l_mark[0].number;
	}
break;
case 54:
#line 589 "parse.y"
	{
		yyval.number = -1;
	}
break;
case 55:
#line 596 "parse.y"
	{
	       struct cache	*cache;

	       TAILQ_FOREACH(cache, &conf.caches, entry) {
		       if (strcmp(cache->path, yystack.l_mark[-1].string) == 0)
			       yyerror("duplicate cache path");
	       }

	       cache = xcalloc(1, sizeof *cache);
	       cache->path = yystack.l_mark[-1].string;
	       cache->expire = yystack.l_mark[0].number;

	       TAILQ_INSERT_TAIL(&conf.caches, cache, entry);

	       log_debug2("added cache \"%s\": expire %lld", cache->path, yystack.l_mark[0].number);
       }
break;
case 56:
#line 616 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("zero maximum size");
	     if (yystack.l_mark[0].number > MAXMAILSIZE)
		     yyerror("maximum size too large: %lld", yystack.l_mark[0].number);
	     conf.max_size = yystack.l_mark[0].number;
     }
break;
case 57:
#line 625 "parse.y"
	{
	     if (yystack.l_mark[0].locks & LOCK_FCNTL && yystack.l_mark[0].locks & LOCK_FLOCK)
		     yyerror("fcntl and flock locking cannot be used together");
	     conf.lock_types = yystack.l_mark[0].locks;
     }
break;
case 58:
#line 632 "parse.y"
	{
	     if (conf.lock_file != NULL)
		     xfree(conf.lock_file);
	     conf.lock_file = yystack.l_mark[0].string;
     }
break;
case 59:
#line 638 "parse.y"
	{
	     conf.del_big = 1;
     }
break;
case 60:
#line 642 "parse.y"
	{
	     conf.allow_many = 1;
     }
break;
case 61:
#line 647 "parse.y"
	{
	     if (conf.def_user == NULL)
		     conf.def_user = yystack.l_mark[0].string;
     }
break;
case 62:
#line 653 "parse.y"
	{
	     if (conf.cmd_user == NULL)
		     conf.cmd_user = yystack.l_mark[0].string;
     }
break;
case 63:
#line 659 "parse.y"
	{
	     xfree(conf.strip_chars);
	     conf.strip_chars = yystack.l_mark[0].string;
     }
break;
case 64:
#line 665 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("zero timeout");
	     if (yystack.l_mark[0].number > INT_MAX / 1000)
		     yyerror("timeout too long: %lld", yystack.l_mark[0].number);
	     conf.timeout = yystack.l_mark[0].number * 1000;
     }
break;
case 65:
#line 674 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("zero queue-high");
	     if (yystack.l_mark[0].number > MAXQUEUEVALUE)
		     yyerror("queue-high too big: %lld", yystack.l_mark[0].number);
	     if (conf.queue_low != -1 && yystack.l_mark[0].number <= conf.queue_low)
		     yyerror("queue-high must be larger than queue-low");
	     conf.queue_high = yystack.l_mark[0].number;
     }
break;
case 66:
#line 685 "parse.y"
	{
	     if (yystack.l_mark[0].number > MAXQUEUEVALUE)
		     yyerror("queue-low too big: %lld", yystack.l_mark[0].number);
	     if (conf.queue_high == -1)
		     yyerror("queue-high not specified");
	     if (yystack.l_mark[0].number >= conf.queue_high)
		     yyerror("queue-low must be smaller than queue-high");
	     conf.queue_low = yystack.l_mark[0].number;
     }
break;
case 67:
#line 696 "parse.y"
	{
	     if (yystack.l_mark[0].number > INT_MAX)
		     yyerror("parallel-accounts too big: %lld", yystack.l_mark[0].number);
	     if (yystack.l_mark[0].number == 0)
		     yyerror("parallel-accounts cannot be zero");
	     conf.max_accts = yystack.l_mark[0].number;
     }
break;
case 68:
#line 705 "parse.y"
	{
	     if (conf.proxy != NULL) {
		     xfree(conf.proxy->server.host);
		     xfree(conf.proxy->server.port);
		     if (conf.proxy->user != NULL)
			     xfree(conf.proxy->user);
		     if (conf.proxy->pass != NULL)
			     xfree(conf.proxy->pass);
	     }
	     if ((conf.proxy = getproxy(yystack.l_mark[0].string)) == NULL)
		     yyerror("invalid proxy");
	     xfree(yystack.l_mark[0].string);
     }
break;
case 69:
#line 719 "parse.y"
	{
	     conf.verify_certs = 1;
     }
break;
case 70:
#line 723 "parse.y"
	{
	     conf.impl_act = DECISION_KEEP;
     }
break;
case 71:
#line 727 "parse.y"
	{
	     conf.impl_act = DECISION_DROP;
     }
break;
case 72:
#line 732 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("invalid purge-after value: 0");
	     if (yystack.l_mark[0].number > UINT_MAX)
		     yyerror("purge-after value too large: %lld", yystack.l_mark[0].number);

	     conf.purge_after = yystack.l_mark[0].number;
     }
break;
case 73:
#line 741 "parse.y"
	{
	     conf.purge_after = 0;
     }
break;
case 74:
#line 745 "parse.y"
	{
	     conf.no_received = 1;
     }
break;
case 75:
#line 749 "parse.y"
	{
	     conf.no_create = 1;
     }
break;
case 76:
#line 753 "parse.y"
	{
	     conf.file_group = -1;
     }
break;
case 77:
#line 758 "parse.y"
	{
	     conf.file_group = yystack.l_mark[0].localgid;
     }
break;
case 78:
#line 762 "parse.y"
	{
	     conf.file_umask = umask(0);
	     umask(conf.file_umask);
     }
break;
case 79:
#line 768 "parse.y"
	{
	     ARRAY_FREEALL(conf.user_order);
	     conf.user_order = yystack.l_mark[0].ufns;
     }
break;
case 80:
#line 774 "parse.y"
	{
	     char	s[8];
	     u_int	n;

	     /*
	      * We can't differentiate umasks in octal from normal numbers
	      * (requiring a leading zero a la C would be nice, but it would
	      * potentially break existing configs), so we need to fiddle to
	      * convert.
	      */
	     memset(s, 0, sizeof s);
	     xsnprintf(s, sizeof s, "%03lld", yystack.l_mark[0].number);
	     if (s[3] != '\0' || s[0] < '0' || s[0] > '7' ||
		 s[1] < 0 || s[1] > '7' || s[2] < '0' || s[2] > '7')
		     yyerror("invalid umask: %s", s);
	     if (sscanf(s, "%o", &n) != 1)
		     yyerror("invalid umask: %s", s);
	     conf.file_umask = n;
     }
break;
case 81:
#line 797 "parse.y"
	{
		  struct macro	*macro;

		  if (strlen(yystack.l_mark[-2].string) > MAXNAMESIZE)
			  yyerror("macro name too long: %s", yystack.l_mark[-2].string);

		  macro = xmalloc(sizeof *macro);
		  strlcpy(macro->name, yystack.l_mark[-2].string, sizeof macro->name);
		  macro->type = MACRO_STRING;
		  macro->value.str = yystack.l_mark[0].string;

		  if (parse_last == NULL)
			  TAILQ_INSERT_HEAD(&parse_macros, macro, entry);
		  else {
			  TAILQ_INSERT_AFTER(
			      &parse_macros, parse_last, macro, entry);
		  }

		  log_debug3("added macro \"%s\": \"%s\"", macro->name,
		      macro->value.str);
		  xfree(yystack.l_mark[-2].string);
	  }
break;
case 82:
#line 821 "parse.y"
	{
		  struct macro	*macro;

		  if (strlen(yystack.l_mark[-2].string) > MAXNAMESIZE)
			  yyerror("macro name too long: %s", yystack.l_mark[-2].string);

		  macro = xmalloc(sizeof *macro);
		  strlcpy(macro->name, yystack.l_mark[-2].string, sizeof macro->name);
		  macro->type = MACRO_NUMBER;
		  macro->value.num = yystack.l_mark[0].number;

		  if (parse_last == NULL)
			  TAILQ_INSERT_HEAD(&parse_macros, macro, entry);
		  else {
			  TAILQ_INSERT_AFTER(
			      &parse_macros, parse_last, macro, entry);
		  }

		  log_debug3("added macro \"%s\": %lld", macro->name,
		      macro->value.num);
		  xfree(yystack.l_mark[-2].string);
	  }
break;
case 83:
#line 847 "parse.y"
	{
		      if (*yystack.l_mark[0].string == '\0')
			      yyerror("empty string in list");

		      yyval.replstrs = yystack.l_mark[-1].replstrs;
		      ARRAY_EXPAND(yyval.replstrs, 1);
		      ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	      }
break;
case 84:
#line 857 "parse.y"
	{
		      if (*yystack.l_mark[0].string == '\0')
			     yyerror("empty string in list");

		      yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		      ARRAY_INIT(yyval.replstrs);
		      ARRAY_EXPAND(yyval.replstrs, 1);
		      ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	      }
break;
case 85:
#line 870 "parse.y"
	{
		     if (*yystack.l_mark[0].string == '\0')
			     yyerror("empty string in list");

		     yyval.strings = yystack.l_mark[-1].strings;
		     ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	     }
break;
case 86:
#line 879 "parse.y"
	{
		     if (*yystack.l_mark[0].string == '\0')
			     yyerror("empty string in list");

		     yyval.strings = xmalloc(sizeof *yyval.strings);
		     ARRAY_INIT(yyval.strings);
		     ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	     }
break;
case 87:
#line 891 "parse.y"
	{
		   if (*yystack.l_mark[0].string == '\0')
			   yyerror("invalid path");

		   yyval.strings = yystack.l_mark[-1].strings;
		   ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	   }
break;
case 88:
#line 900 "parse.y"
	{
		   if (*yystack.l_mark[0].string == '\0')
			   yyerror("invalid path");

		   yyval.strings = xmalloc(sizeof *yyval.strings);
		   ARRAY_INIT(yyval.strings);
		   ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	   }
break;
case 89:
#line 911 "parse.y"
	{
	     yyval.ufn = &passwd_lookup;
     }
break;
case 90:
#line 915 "parse.y"
	{
#ifdef LOOKUP_COURIER
	     yyval.ufn = &courier_lookup;
#else
	     yyerror("support for lookup-order courier is not enabled");
#endif
     }
break;
case 91:
#line 926 "parse.y"
	{
		 yyval.ufns = yystack.l_mark[-1].ufns;
		 ARRAY_ADD(yyval.ufns, yystack.l_mark[0].ufn);
	 }
break;
case 92:
#line 932 "parse.y"
	{
		 yyval.ufns = xmalloc(sizeof *yyval.ufns);
		 ARRAY_INIT(yyval.ufns);
		 ARRAY_ADD(yyval.ufns, yystack.l_mark[0].ufn);
	 }
break;
case 93:
#line 941 "parse.y"
	{
		   if (*yystack.l_mark[0].string == '\0')
			   yyerror("invalid header");

		   yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		   ARRAY_INIT(yyval.replstrs);
		   ARRAY_EXPAND(yyval.replstrs, 1);
		   ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	   }
break;
case 94:
#line 952 "parse.y"
	{
		   yyval.replstrs = yystack.l_mark[-1].replstrs;
	   }
break;
case 95:
#line 959 "parse.y"
	{
		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid path");

		  yyval.strings = xmalloc(sizeof *yyval.strings);
		  ARRAY_INIT(yyval.strings);
		  ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	  }
break;
case 96:
#line 969 "parse.y"
	{
		  yyval.strings = yystack.l_mark[-1].strings;
	  }
break;
case 97:
#line 976 "parse.y"
	{
		if (*yystack.l_mark[0].string == '\0')
			yyerror("invalid path");

		yyval.strings = xmalloc(sizeof *yyval.strings);
		ARRAY_INIT(yyval.strings);
		ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	}
break;
case 98:
#line 986 "parse.y"
	{
		yyval.strings = yystack.l_mark[-1].strings;
	}
break;
case 99:
#line 993 "parse.y"
	{
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid folder");

		 yyval.strings = xmalloc(sizeof *yyval.strings);
		 ARRAY_INIT(yyval.strings);
		 ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	 }
break;
case 100:
#line 1003 "parse.y"
	{
		 yyval.strings = yystack.l_mark[-1].strings;
	 }
break;
case 101:
#line 1009 "parse.y"
	{
	      yyval.locks = LOCK_FCNTL;
      }
break;
case 102:
#line 1013 "parse.y"
	{
	      yyval.locks = LOCK_FLOCK;
      }
break;
case 103:
#line 1017 "parse.y"
	{
	      yyval.locks = LOCK_DOTLOCK;
      }
break;
case 104:
#line 1024 "parse.y"
	{
		  yyval.locks = yystack.l_mark[-1].locks | yystack.l_mark[0].locks;
	  }
break;
case 105:
#line 1029 "parse.y"
	{
		  yyval.locks = yystack.l_mark[0].locks;
	  }
break;
case 106:
#line 1033 "parse.y"
	{
		  yyval.locks = 0;
	  }
break;
case 107:
#line 1040 "parse.y"
	{
		  struct group	*gr;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid group");

		  gr = getgrnam(yystack.l_mark[0].string);
		  if (gr == NULL)
			  yyerror("unknown group: %s", yystack.l_mark[0].string);
		  yyval.localgid = gr->gr_gid;
		  endgrent();

		  xfree(yystack.l_mark[0].string);
	  }
break;
case 108:
#line 1056 "parse.y"
	{
		  struct group	*gr;

		  if (yystack.l_mark[0].number > GID_MAX)
			  yyerror("invalid gid: %llu", yystack.l_mark[0].number);
		  gr = getgrgid(yystack.l_mark[0].number);
		  if (gr == NULL)
			  yyerror("unknown gid: %llu", yystack.l_mark[0].number);
		  yyval.localgid = gr->gr_gid;
		  endgrent();
	  }
break;
case 109:
#line 1070 "parse.y"
	{
	      yyval.string = NULL;
      }
break;
case 110:
#line 1075 "parse.y"
	{
	      yyval.string = yystack.l_mark[0].string;
      }
break;
case 111:
#line 1081 "parse.y"
	{
	       yyval.replstrs = NULL;
       }
break;
case 112:
#line 1086 "parse.y"
	{
	       yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
	       ARRAY_INIT(yyval.replstrs);
	       ARRAY_EXPAND(yyval.replstrs, 1);
	       ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
       }
break;
case 113:
#line 1094 "parse.y"
	{
	       yyval.replstrs = yystack.l_mark[-1].replstrs;
       }
break;
case 114:
#line 1101 "parse.y"
	{
		/* match case */
		yyval.re.flags = 0;
		yyval.re.str = yystack.l_mark[0].string;
        }
break;
case 115:
#line 1108 "parse.y"
	{
		/* ignore case */
		yyval.re.flags = RE_IGNCASE;
		yyval.re.str = yystack.l_mark[0].string;
	}
break;
case 116:
#line 1116 "parse.y"
	{
	      yyval.flag = 1;
      }
break;
case 117:
#line 1120 "parse.y"
	{
	      yyval.flag = 0;
      }
break;
case 118:
#line 1126 "parse.y"
	{
	      yyval.flag = 1;
      }
break;
case 119:
#line 1130 "parse.y"
	{
	      yyval.flag = 0;
      }
break;
case 120:
#line 1136 "parse.y"
	{
		  yyval.flag = 1;
          }
break;
case 121:
#line 1140 "parse.y"
	{
		  yyval.flag = 0;
	  }
break;
case 122:
#line 1147 "parse.y"
	{
	      if (*yystack.l_mark[0].string == '\0')
		      yyerror("invalid port");

	      yyval.string = yystack.l_mark[0].string;
      }
break;
case 123:
#line 1155 "parse.y"
	{
	      if (yystack.l_mark[0].number == 0 || yystack.l_mark[0].number > 65535)
		      yyerror("invalid port");

	      xasprintf(&yyval.string, "%lld", yystack.l_mark[0].number);
      }
break;
case 124:
#line 1165 "parse.y"
	{
		if (*yystack.l_mark[-1].string == '\0')
			yyerror("invalid host");

		yyval.server.host = yystack.l_mark[-1].string;
		yyval.server.port = yystack.l_mark[0].string;
	}
break;
case 125:
#line 1174 "parse.y"
	{
		if (*yystack.l_mark[0].string == '\0')
			yyerror("invalid host");

		yyval.server.host = yystack.l_mark[0].string;
		yyval.server.port = NULL;
	}
break;
case 126:
#line 1184 "parse.y"
	{
	    yyval.string = NULL;
    }
break;
case 127:
#line 1189 "parse.y"
	{
	    yyval.string = yystack.l_mark[0].string;
    }
break;
case 128:
#line 1195 "parse.y"
	{
	      yyval.string = NULL;
      }
break;
case 129:
#line 1200 "parse.y"
	{
	      yyval.string = yystack.l_mark[0].string;
      }
break;
case 130:
#line 1206 "parse.y"
	{
		  yyval.flag = 1;
	  }
break;
case 131:
#line 1210 "parse.y"
	{
		  yyval.flag = 0;
	  }
break;
case 132:
#line 1217 "parse.y"
	{
		 struct deliver_pipe_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid command");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_pipe;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->pipe = yystack.l_mark[-1].flag;
		 data->cmd.str = yystack.l_mark[0].string;
	 }
break;
case 133:
#line 1234 "parse.y"
	{
		 struct deliver_rewrite_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid command");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_rewrite;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->cmd.str = yystack.l_mark[0].string;
	 }
break;
case 134:
#line 1250 "parse.y"
	{
		 struct deliver_write_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid path");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_write;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->append = yystack.l_mark[-1].flag;
		 data->path.str = yystack.l_mark[0].string;
	 }
break;
case 135:
#line 1267 "parse.y"
	{
		 struct deliver_maildir_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid path");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_maildir;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->path.str = yystack.l_mark[0].string;
	 }
break;
case 136:
#line 1283 "parse.y"
	{
		 struct deliver_remove_header_data *data;

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_remove_header;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->hdrs = yystack.l_mark[0].replstrs;
	 }
break;
case 137:
#line 1296 "parse.y"
	{
		 struct deliver_add_header_data	*data;

		 if (*yystack.l_mark[-1].string == '\0')
			 yyerror("invalid header");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_add_header;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->hdr.str = yystack.l_mark[-1].string;
		 data->value.str = yystack.l_mark[0].string;
	 }
break;
case 138:
#line 1313 "parse.y"
	{
		 struct deliver_mbox_data	*data;

		 if (*yystack.l_mark[-1].string == '\0')
			 yyerror("invalid path");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_mbox;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->path.str = yystack.l_mark[-1].string;
		 data->compress = yystack.l_mark[0].flag;
	 }
break;
case 139:
#line 1333 "parse.y"
	{
		 struct deliver_imap_data	*data;

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_imap;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 if (yystack.l_mark[-5].userpass.user_netrc && yystack.l_mark[-5].userpass.pass_netrc)
			 find_netrc(yystack.l_mark[-6].server.host, &data->user, &data->pass);
		 else {
			 if (yystack.l_mark[-5].userpass.user_netrc)
				 find_netrc(yystack.l_mark[-6].server.host, &data->user, NULL);
			 else
				 data->user = yystack.l_mark[-5].userpass.user;
			 if (yystack.l_mark[-5].userpass.pass_netrc)
				 find_netrc(yystack.l_mark[-6].server.host, NULL, &data->pass);
			 else
				 data->pass = yystack.l_mark[-5].userpass.pass;
		 }

		 data->folder.str = yystack.l_mark[-4].string;
		 data->server.ssl = yystack.l_mark[-7].flag;
		 data->server.verify = yystack.l_mark[-3].flag;
		 data->server.tls1 = yystack.l_mark[0].flag;
		 data->server.host = yystack.l_mark[-6].server.host;
		 if (yystack.l_mark[-6].server.port != NULL)
			 data->server.port = yystack.l_mark[-6].server.port;
		 else if (yystack.l_mark[-7].flag)
			 data->server.port = xstrdup("imaps");
		 else
			 data->server.port = xstrdup("imap");
		 data->server.ai = NULL;
		 data->nocrammd5 = yystack.l_mark[-2].flag;
		 data->nologin = yystack.l_mark[-1].flag;
	 }
break;
case 140:
#line 1373 "parse.y"
	{
		 struct deliver_smtp_data	*data;

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_smtp;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->server.host = yystack.l_mark[-2].server.host;
		 if (yystack.l_mark[-2].server.port != NULL)
			 data->server.port = yystack.l_mark[-2].server.port;
		 else
			 data->server.port = xstrdup("smtp");
		 data->server.ai = NULL;
		 data->from.str = yystack.l_mark[-1].string;
		 data->to.str = yystack.l_mark[0].string;
	 }
break;
case 141:
#line 1392 "parse.y"
	{
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_stdout;
	 }
break;
case 142:
#line 1398 "parse.y"
	{
		 struct deliver_tag_data	*data;

		 if (*yystack.l_mark[-1].string == '\0')
			 yyerror("invalid tag");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_tag;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->key.str = yystack.l_mark[-1].string;
		 data->value.str = yystack.l_mark[0].string;
	 }
break;
case 143:
#line 1415 "parse.y"
	{
		 struct deliver_add_to_cache_data	*data;

		 if (*yystack.l_mark[-2].string == '\0')
			 yyerror("invalid path");
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid key");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_add_to_cache;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->key.str = yystack.l_mark[0].string;
		 data->path = yystack.l_mark[-2].string;
	 }
break;
case 144:
#line 1434 "parse.y"
	{
		 struct deliver_remove_from_cache_data	*data;

		 if (*yystack.l_mark[-2].string == '\0')
			 yyerror("invalid path");
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid key");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_remove_from_cache;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->key.str = yystack.l_mark[0].string;
		 data->path = yystack.l_mark[-2].string;
	 }
break;
case 145:
#line 1453 "parse.y"
	{
		 struct deliver_action_data	*data;

		 /*
		  * This is a special-case, handled when the list of delivery
		  * targets is resolved rather than by calling a deliver
		  * function, so the deliver pointer is NULL.
		  */
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = NULL;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->actions = yystack.l_mark[0].replstrs;
 	 }
break;
case 146:
#line 1470 "parse.y"
	{
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_drop;
	 }
break;
case 147:
#line 1475 "parse.y"
	{
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_keep;
	 }
break;
case 148:
#line 1483 "parse.y"
	{
		 yyval.actlist = yystack.l_mark[-1].actlist;

		 TAILQ_INSERT_TAIL(yyval.actlist, yystack.l_mark[0].actitem, entry);
		 yystack.l_mark[0].actitem->idx = parse_actionidx++;
	 }
break;
case 149:
#line 1491 "parse.y"
	{
		 yyval.actlist = xmalloc(sizeof *yyval.actlist);
		 TAILQ_INIT(yyval.actlist);

		 TAILQ_INSERT_HEAD(yyval.actlist, yystack.l_mark[0].actitem, entry);
		 yystack.l_mark[0].actitem->idx = 0;

		 parse_actionidx = 1;
	 }
break;
case 150:
#line 1505 "parse.y"
	{
		   struct action	*t;

		   if (strlen(yystack.l_mark[-2].string) >= MAXNAMESIZE)
			   yyerror("action name too long: %s", yystack.l_mark[-2].string);
		   if (*yystack.l_mark[-2].string == '\0')
			   yyerror("invalid action name");
		   if (find_action(yystack.l_mark[-2].string) != NULL)
			   yyerror("duplicate action: %s", yystack.l_mark[-2].string);

		   t = xmalloc(sizeof *t);
		   strlcpy(t->name, yystack.l_mark[-2].string, sizeof t->name);

		   t->list = xmalloc(sizeof *t->list);
		   TAILQ_INIT(t->list);
		   TAILQ_INSERT_HEAD(t->list, yystack.l_mark[0].actitem, entry);
		   yystack.l_mark[0].actitem->idx = 0;

		   t->users = yystack.l_mark[-1].replstrs;
		   TAILQ_INSERT_TAIL(&conf.actions, t, entry);

		   print_action(t);

		   xfree(yystack.l_mark[-2].string);
	   }
break;
case 151:
#line 1533 "parse.y"
	{
		   struct action	*t;

		   if (strlen(yystack.l_mark[-4].string) >= MAXNAMESIZE)
			   yyerror("action name too long: %s", yystack.l_mark[-4].string);
		   if (*yystack.l_mark[-4].string == '\0')
			   yyerror("invalid action name");
		   if (find_action(yystack.l_mark[-4].string) != NULL)
			   yyerror("duplicate action: %s", yystack.l_mark[-4].string);

		   t = xmalloc(sizeof *t);
		   strlcpy(t->name, yystack.l_mark[-4].string, sizeof t->name);

		   t->list = yystack.l_mark[-1].actlist;

		   t->users = yystack.l_mark[-3].replstrs;
		   TAILQ_INSERT_TAIL(&conf.actions, t, entry);

		   print_action(t);

		   xfree(yystack.l_mark[-4].string);
	   }
break;
case 152:
#line 1559 "parse.y"
	{
		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid account name");
		  if (!have_accounts(yystack.l_mark[0].string))
			  yyerror("no matching accounts: %s", yystack.l_mark[0].string);

		  yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		  ARRAY_INIT(yyval.replstrs);
		  ARRAY_EXPAND(yyval.replstrs, 1);
		  ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	  }
break;
case 153:
#line 1572 "parse.y"
	{
		  yyval.replstrs = yystack.l_mark[-1].replstrs;
	  }
break;
case 154:
#line 1579 "parse.y"
	{
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid action name");

		 yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		 ARRAY_INIT(yyval.replstrs);
		 ARRAY_EXPAND(yyval.replstrs, 1);
		 ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	 }
break;
case 155:
#line 1590 "parse.y"
	{
		 yyval.replstrs = yystack.l_mark[-1].replstrs;
	 }
break;
case 156:
#line 1596 "parse.y"
	{
	      yyval.flag = 0;
      }
break;
case 157:
#line 1600 "parse.y"
	{
	      yyval.flag = 1;
      }
break;
case 158:
#line 1606 "parse.y"
	{
	      yyval.area = AREA_ANY;
      }
break;
case 159:
#line 1610 "parse.y"
	{
	      yyval.area = AREA_ANY;
      }
break;
case 160:
#line 1614 "parse.y"
	{
	      yyval.area = AREA_HEADERS;
      }
break;
case 161:
#line 1618 "parse.y"
	{
	      yyval.area = AREA_BODY;
      }
break;
case 162:
#line 1625 "parse.y"
	{
	       if (yystack.l_mark[0].number < 0 || yystack.l_mark[0].number > 255)
		       yyerror("invalid return code");

	       yyval.number = yystack.l_mark[0].number;
       }
break;
case 163:
#line 1632 "parse.y"
	{
	       yyval.number = -1;
       }
break;
case 164:
#line 1639 "parse.y"
	{
	       yyval.re = yystack.l_mark[0].re;
       }
break;
case 165:
#line 1643 "parse.y"
	{
	       yyval.re.str = NULL;
       }
break;
case 166:
#line 1649 "parse.y"
	{
	     yyval.cmp = CMP_LT;
     }
break;
case 167:
#line 1653 "parse.y"
	{
	     yyval.cmp = CMP_GT;
     }
break;
case 168:
#line 1659 "parse.y"
	{
	      yyval.cmp = CMP_EQ;
      }
break;
case 169:
#line 1663 "parse.y"
	{
	      yyval.cmp = CMP_NE;
      }
break;
case 170:
#line 1670 "parse.y"
	{
	     yyval.cmp = yystack.l_mark[0].cmp;
     }
break;
case 171:
#line 1675 "parse.y"
	{
	     yyval.cmp = yystack.l_mark[0].cmp;
     }
break;
case 172:
#line 1681 "parse.y"
	{
		  yyval.flag = 0;
	  }
break;
case 173:
#line 1685 "parse.y"
	{
		  yyval.flag = 1;
	  }
break;
case 174:
#line 1691 "parse.y"
	{
		     yyval.flag = 0;
	     }
break;
case 175:
#line 1695 "parse.y"
	{
		     yyval.flag = 1;
	     }
break;
case 176:
#line 1701 "parse.y"
	{
		yyval.exprop = OP_AND;
        }
break;
case 177:
#line 1705 "parse.y"
	{
		yyval.exprop = OP_OR;
	}
break;
case 178:
#line 1712 "parse.y"
	{
		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_all;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;
	  }
break;
case 179:
#line 1720 "parse.y"
	{
		  struct match_regexp_data	*data;
		  char				*cause;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_regexp;
		  yyval.expritem->inverted = yystack.l_mark[-2].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->area = yystack.l_mark[0].area;

		  if (re_compile(&data->re, yystack.l_mark[-1].re.str, yystack.l_mark[-1].re.flags, &cause) != 0)
			  yyerror("%s", cause);
		  xfree(yystack.l_mark[-1].re.str);
	  }
break;
case 180:
#line 1739 "parse.y"
	{
		  struct match_account_data	*data;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_account;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->accounts = yystack.l_mark[0].replstrs;
	  }
break;
case 181:
#line 1755 "parse.y"
	{
		  struct match_command_data	*data;
		  char				*cause;

		  if (*yystack.l_mark[-7].string == '\0' || (yystack.l_mark[-7].string[0] == '|' && yystack.l_mark[-7].string[1] == '\0'))
			  yyerror("invalid command");
		  if (yystack.l_mark[-3].number == -1 && yystack.l_mark[-1].re.str == NULL)
			  yyerror("return code or regexp must be specified");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_command;
		  yyval.expritem->inverted = yystack.l_mark[-9].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->user.str = yystack.l_mark[-6].string;
		  data->pipe = yystack.l_mark[-8].flag;
		  data->cmd.str = yystack.l_mark[-7].string;

		  data->ret = yystack.l_mark[-3].number;

		  if (yystack.l_mark[-1].re.str != NULL) {
			  if (re_compile(
			      &data->re, yystack.l_mark[-1].re.str, yystack.l_mark[-1].re.flags, &cause) != 0)
				  yyerror("%s", cause);
			  xfree(yystack.l_mark[-1].re.str);
		  }

	  }
break;
case 182:
#line 1787 "parse.y"
	{
		  struct match_tagged_data	*data;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid tag");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_tagged;
		  yyval.expritem->inverted = yystack.l_mark[-2].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->tag.str = yystack.l_mark[0].string;
	  }
break;
case 183:
#line 1805 "parse.y"
	{
		  struct match_size_data	*data;

#if SIZE_MAX < LLONG_MAX
		  if (yystack.l_mark[0].number > SIZE_MAX)
			  yyerror("size too large");
#endif

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_size;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->size = yystack.l_mark[0].number;
		  data->cmp = yystack.l_mark[-1].cmp;
	  }
break;
case 184:
#line 1827 "parse.y"
	{
		  struct match_string_data	*data;
		  char				*cause;

		  if (*yystack.l_mark[-2].string == '\0')
			  yyerror("invalid string");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_string;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->str.str = yystack.l_mark[-2].string;
		  if (re_compile(
		      &data->re, yystack.l_mark[0].re.str, yystack.l_mark[0].re.flags|RE_NOSUBST, &cause) != 0)
			  yyerror("%s", cause);
		  xfree(yystack.l_mark[0].re.str);
	  }
break;
case 185:
#line 1850 "parse.y"
	{
		  struct match_in_cache_data	*data;

		  if (*yystack.l_mark[-2].string == '\0')
			  yyerror("invalid path");
		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid key");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_in_cache;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->key.str = yystack.l_mark[0].string;
		  data->path = yystack.l_mark[-2].string;
	  }
break;
case 186:
#line 1871 "parse.y"
	{
		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_matched;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;
          }
break;
case 187:
#line 1879 "parse.y"
	{
		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_unmatched;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;
          }
break;
case 188:
#line 1887 "parse.y"
	{
		  struct match_age_data	*data;

		  if (yystack.l_mark[0].number == 0)
			  yyerror("invalid time");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_age;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->time = yystack.l_mark[0].number;
		  data->cmp = yystack.l_mark[-1].cmp;
	  }
break;
case 189:
#line 1906 "parse.y"
	{
		  struct match_age_data	*data;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_age;
		  yyval.expritem->inverted = yystack.l_mark[-2].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->time = -1;
	  }
break;
case 190:
#line 1921 "parse.y"
	{
		  struct match_attachment_data	*data;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_COUNT;
		  data->cmp = yystack.l_mark[-1].cmp;
		  data->value.num = yystack.l_mark[0].number;
	  }
break;
case 191:
#line 1938 "parse.y"
	{
		  struct match_attachment_data	*data;

#if SIZE_MAX < LLONG_MAX
		  if (yystack.l_mark[0].number > SIZE_MAX)
			  yyerror("size too large");
#endif

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_TOTALSIZE;
		  data->cmp = yystack.l_mark[-1].cmp;
		  data->value.size = yystack.l_mark[0].number;
	  }
break;
case 192:
#line 1960 "parse.y"
	{
		  struct match_attachment_data	*data;

#if SIZE_MAX < LLONG_MAX
		  if (yystack.l_mark[0].number > SIZE_MAX)
			  yyerror("size too large");
#endif

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_ANYSIZE;
		  data->cmp = yystack.l_mark[-1].cmp;
		  data->value.size = yystack.l_mark[0].number;
	  }
break;
case 193:
#line 1982 "parse.y"
	{
		  struct match_attachment_data	*data;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid string");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_ANYTYPE;
		  data->value.str.str = yystack.l_mark[0].string;
	  }
break;
case 194:
#line 2001 "parse.y"
	{
		  struct match_attachment_data	*data;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid string");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_ANYNAME;
		  data->value.str.str = yystack.l_mark[0].string;
	  }
break;
case 195:
#line 2023 "parse.y"
	{
		  yyval.expr = yystack.l_mark[-2].expr;

		  yystack.l_mark[0].expritem->op = yystack.l_mark[-1].exprop;
		  TAILQ_INSERT_TAIL(yyval.expr, yystack.l_mark[0].expritem, entry);
	  }
break;
case 196:
#line 2031 "parse.y"
	{
		  yyval.expr = xmalloc(sizeof *yyval.expr);
		  TAILQ_INIT(yyval.expr);

		  yystack.l_mark[0].expritem->op = yystack.l_mark[-1].exprop;
		  TAILQ_INSERT_HEAD(yyval.expr, yystack.l_mark[0].expritem, entry);
	  }
break;
case 197:
#line 2042 "parse.y"
	{
	      yyval.expr = xmalloc(sizeof *yyval.expr);
	      TAILQ_INIT(yyval.expr);

	      TAILQ_INSERT_HEAD(yyval.expr, yystack.l_mark[0].expritem, entry);
      }
break;
case 198:
#line 2050 "parse.y"
	{
	      yyval.expr = yystack.l_mark[0].expr;

	      TAILQ_INSERT_HEAD(yyval.expr, yystack.l_mark[-1].expritem, entry);
      }
break;
case 199:
#line 2060 "parse.y"
	{
		 struct action	*t;

		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->actions = NULL;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = !yystack.l_mark[0].flag;
		 yyval.rule->users = yystack.l_mark[-3].replstrs;

		 t = yyval.rule->lambda = xcalloc(1, sizeof *yyval.rule->lambda);
		 xsnprintf(t->name, sizeof t->name, "<rule %u>", yyval.rule->idx);
		 t->users = NULL;
		 t->list = xmalloc(sizeof *t->list);
		 TAILQ_INIT(t->list);
		 TAILQ_INSERT_HEAD(t->list, yystack.l_mark[-1].actitem, entry);
		 yystack.l_mark[-1].actitem->idx = 0;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);
	 }
break;
case 200:
#line 2086 "parse.y"
	{
		 struct action	*t;

		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->actions = NULL;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = !yystack.l_mark[0].flag;
		 yyval.rule->users = yystack.l_mark[-5].replstrs;

		 t = yyval.rule->lambda = xcalloc(1, sizeof *yyval.rule->lambda);
		 xsnprintf(t->name, sizeof t->name, "<rule %u>", yyval.rule->idx);
		 t->users = NULL;
		 t->list = yystack.l_mark[-2].actlist;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);
	 }
break;
case 201:
#line 2109 "parse.y"
	{
		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->lambda = NULL;
		 yyval.rule->actions = yystack.l_mark[-1].replstrs;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = !yystack.l_mark[0].flag;
		 yyval.rule->users = yystack.l_mark[-2].replstrs;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);
	 }
break;
case 202:
#line 2124 "parse.y"
	{
		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->lambda = NULL;
		 yyval.rule->actions = NULL;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = 0;
		 yyval.rule->users = NULL;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);

		 ARRAY_ADD(&parse_rulestack, parse_rule);
		 parse_rule = yyval.rule;
	 }
break;
case 203:
#line 2144 "parse.y"
	{
	       if (parse_rule == NULL)
		       yyerror("missing {");

	       parse_rule = ARRAY_LAST(&parse_rulestack);
	       ARRAY_TRUNC(&parse_rulestack, 1);
       }
break;
case 204:
#line 2155 "parse.y"
	{
	      yystack.l_mark[0].rule->expr = yystack.l_mark[-1].expr;
	      print_rule(yystack.l_mark[0].rule);
      }
break;
case 205:
#line 2162 "parse.y"
	{
		    yyval.strings = xmalloc(sizeof *yyval.strings);
		    ARRAY_INIT(yyval.strings);
		    ARRAY_ADD(yyval.strings, xstrdup("INBOX"));
	    }
break;
case 206:
#line 2169 "parse.y"
	{
		    yyval.strings = yystack.l_mark[0].strings;
	    }
break;
case 207:
#line 2175 "parse.y"
	{
		 yyval.string = xstrdup("INBOX");
	 }
break;
case 208:
#line 2180 "parse.y"
	{
		 yyval.string = yystack.l_mark[0].string;
	 }
break;
case 209:
#line 2188 "parse.y"
	{
		if (*yystack.l_mark[0].string == '\0')
			yyerror("invalid group");

		yyval.strings = xmalloc(sizeof *yyval.strings);
		ARRAY_INIT(yyval.strings);
		ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	}
break;
case 210:
#line 2198 "parse.y"
	{
		yyval.strings = yystack.l_mark[-1].strings;
	}
break;
case 211:
#line 2204 "parse.y"
	{
		   yyval.flag = 1;
	   }
break;
case 212:
#line 2208 "parse.y"
	{
		   yyval.flag = 0;
	   }
break;
case 213:
#line 2214 "parse.y"
	{
		 yyval.flag = 1;
	 }
break;
case 214:
#line 2218 "parse.y"
	{
		 yyval.flag = 0;
	 }
break;
case 215:
#line 2224 "parse.y"
	{
		yyval.flag = 0;
	}
break;
case 216:
#line 2228 "parse.y"
	{
		yyval.flag = 1;
	}
break;
case 217:
#line 2234 "parse.y"
	{
		yyval.flag = 0;
	}
break;
case 218:
#line 2238 "parse.y"
	{
		yyval.flag = 1;
	}
break;
case 219:
#line 2244 "parse.y"
	{
		yyval.flag = 0;
	}
break;
case 220:
#line 2248 "parse.y"
	{
		yyval.flag = 1;
	}
break;
case 221:
#line 2254 "parse.y"
	{
	      yyval.flag = 0;
      }
break;
case 222:
#line 2258 "parse.y"
	{
	      yyval.flag = 1;
      }
break;
case 223:
#line 2264 "parse.y"
	{
	      yyval.only = FETCH_ONLY_NEW;
      }
break;
case 224:
#line 2268 "parse.y"
	{
	      yyval.only = FETCH_ONLY_OLD;
      }
break;
case 225:
#line 2274 "parse.y"
	{
		 yyval.flag = 0;
         }
break;
case 226:
#line 2278 "parse.y"
	{
		 yyval.flag = 1;
	 }
break;
case 227:
#line 2284 "parse.y"
	{
		  yyval.flag = 0;
          }
break;
case 228:
#line 2288 "parse.y"
	{
		  yyval.flag = 1;
	  }
break;
case 229:
#line 2294 "parse.y"
	{
		  yyval.flag = 0;
          }
break;
case 230:
#line 2298 "parse.y"
	{
		  yyval.flag = 1;
	  }
break;
case 231:
#line 2305 "parse.y"
	{
		       if (*yystack.l_mark[-2].string == '\0')
			       yyerror("invalid user");
		       if (*yystack.l_mark[0].string == '\0')
			       yyerror("invalid pass");

		       yyval.userpass.user = yystack.l_mark[-2].string;
		       yyval.userpass.user_netrc = 0;
		       yyval.userpass.pass = yystack.l_mark[0].string;
		       yyval.userpass.pass_netrc = 0;
	       }
break;
case 232:
#line 2317 "parse.y"
	{
		       yyval.userpass.user = NULL;
		       yyval.userpass.user_netrc = 1;
		       yyval.userpass.pass = NULL;
		       yyval.userpass.pass_netrc = 1;
	       }
break;
case 233:
#line 2325 "parse.y"
	{
		       if (*yystack.l_mark[0].string == '\0')
			       yyerror("invalid user");

		       yyval.userpass.user = yystack.l_mark[0].string;
		       yyval.userpass.user_netrc = 0;
		       yyval.userpass.pass = NULL;
		       yyval.userpass.pass_netrc = 1;
	       }
break;
case 234:
#line 2336 "parse.y"
	{
		       if (*yystack.l_mark[0].string == '\0')
			       yyerror("invalid pass");

		       yyval.userpass.user = NULL;
		       yyval.userpass.user_netrc = 1;
		       yyval.userpass.pass = yystack.l_mark[0].string;
		       yyval.userpass.pass_netrc = 0;
	       }
break;
case 235:
#line 2349 "parse.y"
	{
		      if (*yystack.l_mark[-2].string == '\0')
			      yyerror("invalid user");
		      if (*yystack.l_mark[0].string == '\0')
			      yyerror("invalid pass");

		      yyval.userpass.user = yystack.l_mark[-2].string;
		      yyval.userpass.user_netrc = 0;
		      yyval.userpass.pass = yystack.l_mark[0].string;
		      yyval.userpass.pass_netrc = 0;
	      }
break;
case 236:
#line 2364 "parse.y"
	{
		  yyval.userpass.user = yystack.l_mark[0].userpass.user;
		  yyval.userpass.user_netrc = yystack.l_mark[0].userpass.user_netrc;
		  yyval.userpass.pass = yystack.l_mark[0].userpass.pass;
		  yyval.userpass.pass_netrc = yystack.l_mark[0].userpass.pass_netrc;
	  }
break;
case 237:
#line 2371 "parse.y"
	{
		  yyval.userpass.user = NULL;
		  yyval.userpass.user_netrc = 0;
		  yyval.userpass.pass = NULL;
		  yyval.userpass.pass_netrc = 0;
	  }
break;
case 238:
#line 2381 "parse.y"
	{
		 yyval.poponly.path = yystack.l_mark[0].string;
		 yyval.poponly.only = yystack.l_mark[-2].only;
	 }
break;
case 239:
#line 2386 "parse.y"
	{
		 yyval.poponly.path = NULL;
		 yyval.poponly.only = FETCH_ONLY_ALL;
	 }
break;
case 240:
#line 2394 "parse.y"
	{
		  yyval.only = yystack.l_mark[0].only;
	  }
break;
case 241:
#line 2398 "parse.y"
	{
		  yyval.only = FETCH_ONLY_ALL;
	  }
break;
case 242:
#line 2408 "parse.y"
	{
		   struct fetch_pop3_data	*data;

		   yyval.fetch.fetch = &fetch_pop3;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;

		   if (yystack.l_mark[-5].userpass.user_netrc && yystack.l_mark[-5].userpass.pass_netrc)
			  find_netrc(yystack.l_mark[-6].server.host, &data->user, &data->pass);
		   else {
			   if (yystack.l_mark[-5].userpass.user_netrc)
				   find_netrc(yystack.l_mark[-6].server.host, &data->user, NULL);
			   else
				   data->user = yystack.l_mark[-5].userpass.user;
			   if (yystack.l_mark[-5].userpass.pass_netrc)
				   find_netrc(yystack.l_mark[-6].server.host, NULL, &data->pass);
			   else
				   data->pass = yystack.l_mark[-5].userpass.pass;
		   }

		   data->server.ssl = yystack.l_mark[-7].flag;
		   data->server.verify = yystack.l_mark[-2].flag;
		   data->server.tls1 = yystack.l_mark[0].flag;
		   data->server.host = yystack.l_mark[-6].server.host;
		   if (yystack.l_mark[-6].server.port != NULL)
			   data->server.port = yystack.l_mark[-6].server.port;
		   else if (yystack.l_mark[-7].flag)
			   data->server.port = xstrdup("pop3s");
		   else
			   data->server.port = xstrdup("pop3");
		   data->server.ai = NULL;
		   data->apop = yystack.l_mark[-3].flag;
		   data->uidl = yystack.l_mark[-1].flag;

		   data->path = yystack.l_mark[-4].poponly.path;
		   data->only = yystack.l_mark[-4].poponly.only;
	   }
break;
case 243:
#line 2449 "parse.y"
	{
		   struct fetch_pop3_data	*data;

		   yyval.fetch.fetch = &fetch_pop3pipe;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->user = yystack.l_mark[-2].userpass.user;
		   data->pass = yystack.l_mark[-2].userpass.pass;
		   data->pipecmd = yystack.l_mark[-3].string;
		   if (data->pipecmd == NULL || *data->pipecmd == '\0')
			   yyerror("invalid pipe command");
		   data->apop = yystack.l_mark[0].flag;
		   data->path = yystack.l_mark[-1].poponly.path;
		   data->only = yystack.l_mark[-1].poponly.only;
	   }
break;
case 244:
#line 2471 "parse.y"
	{
		   struct fetch_imap_data	*data;

		   yyval.fetch.fetch = &fetch_imap;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;

		   if (yystack.l_mark[-6].userpass.user_netrc && yystack.l_mark[-6].userpass.pass_netrc)
			   find_netrc(yystack.l_mark[-7].server.host, &data->user, &data->pass);
		   else {
			   if (yystack.l_mark[-6].userpass.user_netrc)
				   find_netrc(yystack.l_mark[-7].server.host, &data->user, NULL);
			   else
				   data->user = yystack.l_mark[-6].userpass.user;
			   if (yystack.l_mark[-6].userpass.pass_netrc)
				   find_netrc(yystack.l_mark[-7].server.host, NULL, &data->pass);
			   else
				   data->pass = yystack.l_mark[-6].userpass.pass;
		   }

		   data->folders = yystack.l_mark[-5].strings;
		   data->server.ssl = yystack.l_mark[-8].flag;
		   data->server.verify = yystack.l_mark[-3].flag;
		   data->server.tls1 = yystack.l_mark[0].flag;
		   data->server.host = yystack.l_mark[-7].server.host;
		   if (yystack.l_mark[-7].server.port != NULL)
			   data->server.port = yystack.l_mark[-7].server.port;
		   else if (yystack.l_mark[-8].flag)
			   data->server.port = xstrdup("imaps");
		   else
			   data->server.port = xstrdup("imap");
		   data->server.ai = NULL;
		   data->only = yystack.l_mark[-4].only;
		   data->nocrammd5 = yystack.l_mark[-2].flag;
		   data->nologin = yystack.l_mark[-1].flag;
	   }
break;
case 245:
#line 2511 "parse.y"
	{
		   struct fetch_imap_data	*data;

		   yyval.fetch.fetch = &fetch_imappipe;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->user = yystack.l_mark[-2].userpass.user;
		   data->pass = yystack.l_mark[-2].userpass.pass;
		   data->folders = yystack.l_mark[-1].strings;
		   data->pipecmd = yystack.l_mark[-3].string;
		   if (data->pipecmd == NULL || *data->pipecmd == '\0')
			   yyerror("invalid pipe command");
		   data->only = yystack.l_mark[0].only;
	   }
break;
case 246:
#line 2526 "parse.y"
	{
		   yyval.fetch.fetch = &fetch_stdin;
	   }
break;
case 247:
#line 2531 "parse.y"
	{
		   struct fetch_maildir_data	*data;

		   yyval.fetch.fetch = &fetch_maildir;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->maildirs = yystack.l_mark[0].strings;
	   }
break;
case 248:
#line 2541 "parse.y"
	{
		   struct fetch_mbox_data	*data;

		   yyval.fetch.fetch = &fetch_mbox;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->mboxes = yystack.l_mark[0].strings;
	   }
break;
case 249:
#line 2554 "parse.y"
	{
		   struct fetch_nntp_data	*data;
		   char				*cause;

		   if (*yystack.l_mark[-2].string == '\0')
			   yyerror("invalid cache");

		   yyval.fetch.fetch = &fetch_nntp;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;

		   if (yystack.l_mark[-5].userpass.user_netrc && yystack.l_mark[-5].userpass.pass_netrc) {
			   if (find_netrc1(yystack.l_mark[-6].server.host,
			       &data->user, &data->pass, &cause) != 0) {
				   log_debug2("%s", cause);
				   xfree(cause);
				   data->user = NULL;
				   data->pass = NULL;
			   }

		   } else {
			   if (yystack.l_mark[-5].userpass.user_netrc)
				   find_netrc(yystack.l_mark[-6].server.host, &data->user, NULL);
			   else
				   data->user = yystack.l_mark[-5].userpass.user;
			   if (yystack.l_mark[-5].userpass.pass_netrc)
				   find_netrc(yystack.l_mark[-6].server.host, NULL, &data->pass);
			   else
				   data->pass = yystack.l_mark[-5].userpass.pass;
		   }

		   data->names = yystack.l_mark[-4].strings;
		   data->path = yystack.l_mark[-2].string;
		   if (data->path == NULL || *data->path == '\0')
			   yyerror("invalid cache");

		   data->server.ssl = yystack.l_mark[-7].flag;
		   data->server.verify = yystack.l_mark[-1].flag;
		   data->server.tls1 = yystack.l_mark[0].flag;
		   data->server.host = yystack.l_mark[-6].server.host;
		   if (yystack.l_mark[-6].server.port != NULL)
			   data->server.port = yystack.l_mark[-6].server.port;
		   else if (yystack.l_mark[-7].flag)
                           data->server.port = xstrdup("nntps");
                   else
			   data->server.port = xstrdup("nntp");
		   data->server.ai = NULL;
	   }
break;
case 250:
#line 2608 "parse.y"
	{
		 struct account		*a;
		 char			*su, desc[DESCBUFSIZE];

		 if (strlen(yystack.l_mark[-4].string) >= MAXNAMESIZE)
			 yyerror("account name too long: %s", yystack.l_mark[-4].string);
		 if (*yystack.l_mark[-4].string == '\0')
			 yyerror("invalid account name");
		 if (find_account(yystack.l_mark[-4].string) != NULL)
			 yyerror("duplicate account: %s", yystack.l_mark[-4].string);

		 a = xcalloc(1, sizeof *a);
		 strlcpy(a->name, yystack.l_mark[-4].string, sizeof a->name);
		 a->keep = yystack.l_mark[0].flag;
		 a->disabled = yystack.l_mark[-3].flag;
		 a->users = yystack.l_mark[-2].replstrs;
		 a->fetch = yystack.l_mark[-1].fetch.fetch;
		 a->data = yystack.l_mark[-1].fetch.data;
		 TAILQ_INSERT_TAIL(&conf.accounts, a, entry);

		 if (a->users != NULL)
			 su = fmt_replstrs(" users=", a->users);
		 else
			 su = xstrdup("");
		 a->fetch->desc(a, desc, sizeof desc);
		 log_debug2("added account \"%s\":%s fetch=%s", a->name, su,
		     desc);
		 xfree(su);

		 xfree(yystack.l_mark[-4].string);
	 }
break;
#line 4267 "y.tab.c"
    }
    yystack.s_mark -= yym;
    yystate = *yystack.s_mark;
    yystack.l_mark -= yym;
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: after reduction, shifting from state 0 to\
 state %d\n", YYPREFIX, YYFINAL);
#endif
        yystate = YYFINAL;
        *++yystack.s_mark = YYFINAL;
        *++yystack.l_mark = yyval;
        if (yychar < 0)
        {
            if ((yychar = YYLEX) < 0) yychar = 0;
#if YYDEBUG
            if (yydebug)
            {
                yys = 0;
                if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
                if (!yys) yys = "illegal-symbol";
                printf("%sdebug: state %d, reading %d (%s)\n",
                        YYPREFIX, YYFINAL, yychar, yys);
            }
#endif
        }
        if (yychar == 0) goto yyaccept;
        goto yyloop;
    }
    if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: after reduction, shifting from state %d \
to state %d\n", YYPREFIX, *yystack.s_mark, yystate);
#endif
    if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
    {
        goto yyoverflow;
    }
    *++yystack.s_mark = (short) yystate;
    *++yystack.l_mark = yyval;
    goto yyloop;

yyoverflow:
    yyerror("yacc stack overflow");

yyabort:
    yyfreestack(&yystack);
    return (1);

yyaccept:
    yyfreestack(&yystack);
    return (0);
}
